@@ -19,32 +19,28 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "default_include.h"
+
+#include <unistd.h>
+#include <string.h>
+#include <errno.h>
 #include <stdlib.h>
-#include "config.h"				/* must be before the gdk_imlib !!!!! */
+#include <stdio.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <locale.h>
 
 #if HAVE_LIBGDK_IMLIB
 #include <gdk_imlib.h>
 #endif
 
-#include <gtk/gtk.h>
-#include <unistd.h>
-#include <string.h>
-#include <errno.h>
-#include <stdio.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-
-#include <locale.h>
-#include <libintl.h>
-
-#include "intl.h"
 #include "bluefish.h"
+#include "init.h"				/* parse commandline */
+#include "gtk_easy.h"			/* window_destroy */
 #include "interface.h"
 #include "callbacks.h"
-#include "commandline.h"
-#include "debug.h"
 
-mainstruct *main_v;
+Tmain *main_v;
 
 /****************************************************************************/
 
@@ -69,25 +65,40 @@ static void close_modal_window_lcb(GtkWidget * widget, gpointer window);
 /****************************************************************************/
 void cya_later(GtkWidget * widget, gpointer data)
 {
-
-	file_close_all_cb(NULL, NULL);
+	DEBUG_MSG("cya_later, calling project_close_cb(NULL, NULL);\n");
 	project_close_cb(NULL, NULL);
-	if (g_list_length(main_v->documentlist) > 1) {
-		if ((g_list_length(main_v->documentlist) == 2)
+	DEBUG_MSG("cya_later, calling file_close_all_cb(NULL, NULL);\n");
+	file_close_all_cb(NULL, NULL);
+	if (g_list_length(main_v->documentlist) > 0) {
+		if ((g_list_length(main_v->documentlist) == 1)
 			&& (main_v->current_document->modified == 0)) {
 			DEBUG_MSG("cya_later, doesn't matter, 1 file and not modified\n");
-			gtk_main_quit();
 		} else {
 			DEBUG_MSG("cya_later, not all documents are closed\n");
+			return;
 		}
-	} else {
-		gtk_main_quit();
 	}
+#ifdef DEVELOPMENT
+/* for memory leak debugging */
+	gtk_widget_destroy(main_v->main_window);
+	flush_queue();
+	g_free(main_v);
+#endif
+	gtk_main_quit();
 }
 
 int main(gint argc, gchar * argv[])
 {
-	/* for international language support */
+
+	GList *tmplist;
+
+	/* init locale before any *_init */
+	setlocale(LC_ALL, "");
+	bindtextdomain(PACKAGE, LOCALEDIR);
+	textdomain(PACKAGE);
+
+	/* for XIM support we need to call gtk_set_locale() before gdk_init() */
+	gtk_set_locale();
 	gdk_init(&argc, &argv);
 
 #if HAVE_LIBGDK_IMLIB
@@ -95,15 +106,8 @@ int main(gint argc, gchar * argv[])
 	gdk_imlib_init();
 #endif
 
-	/* create the window widget and start gtk */
 	gtk_init(&argc, &argv);
 
-	gtk_set_locale();
-	setlocale(LC_NUMERIC, "C");
-
-	bindtextdomain(PACKAGE, LOCALEDIR);
-	textdomain(PACKAGE);
-
 	parse_commandline(argc, argv);
 
 	/* see if we're running as root, if so, exit with an error unless overriden */
@@ -123,7 +127,7 @@ int main(gint argc, gchar * argv[])
 	DEBUG_MSG("main, 1 g_get_home_dir=%s\n", g_get_home_dir());
 
 	/*initialise the main struct */
-	main_v = g_malloc0(sizeof(mainstruct));
+	main_v = g_malloc0(sizeof(Tmain));
 
 	/* display a splash screen with progress bar
 	 * also creates the main window, reads the config, 
@@ -131,9 +135,14 @@ int main(gint argc, gchar * argv[])
 	 */
 	startup();
 	DEBUG_MSG("main, startup() finished\n");
-	if (load_filename) {
-		file_open(load_filename);
-		g_free(load_filename);
+	if (load_filenames) {
+		tmplist = g_list_first(load_filenames);
+		while (tmplist) {
+			file_open((gchar *) tmplist->data);
+			tmplist = g_list_next(tmplist);
+		}
+		/* the strings don't need to be freed, they're needed in the project anyway */
+		g_list_free(load_filenames);
 	}
 	DEBUG_MSG("main, load file from commandline finished\n");
 	if ((load_projectname) && (file_exists_and_readable(load_projectname))) {
@@ -143,8 +152,8 @@ int main(gint argc, gchar * argv[])
 	}
 	DEBUG_MSG("main, going into gtk_main()\n");
 	gtk_main();
-
-	exit(0);
+	gtk_exit(0);
+	return (0);
 }
 
 /*
@@ -241,14 +250,151 @@ gchar *strip_common_path(char *image_fn, char *html_fn)
 	return tempstr;
 	/* the function that calls this one must use gfree() somewhere!! */
 }
+/*
+ * Function: most_efficient_filename
+ * Arguments:
+ *      filename: the string which will be modified to remove dir/../
+ * Return value:
+ *      the same string, but modified this time
+ * Description:
+ *      remove not wanted dir/../ from filenames
+ */
+gchar *most_efficient_filename(gchar *filename) {
+	gint i,j, len;
 
+	DEBUG_MSG("most_efficient_filename, 1 filename=%s\n", filename);
+	len = strlen(filename);
+	for (i=0; i < len-4; i++) {
+/*		DEBUG_MSG("most_efficient_filename, i=%d\n", i); */
+		if (strncmp(&filename[i], "/../", 4) == 0) {
+			for (j=1; j < i; j++) {
+				if ((filename[i - j] == '/') || (i==j)) {
+					DEBUG_MSG("most_efficient_filename, &filename[%d-%d]=%s, &filename[%d+3]=%s, %d-%d-4=%d\n", i,j,&filename[i-j],i, &filename[i+3], len, j, len-j-4);
+					memmove(&filename[i-j], &filename[i+3], len-i);
+					j=i;
+					i--;
+				}
+			}
+		}
+	}
+	DEBUG_MSG("most_efficient_filename, 3 filename=%s\n", filename);
+	return filename;
+}
 
-
-void window_close(GtkWidget * button, gpointer windowname)
+/*
+ * Function: create_relative_link_to
+ * Arguments:
+ * 	current_filepath: the file to link FROM, a full path
+ * 	link_to_filepath: the file to link TO, a full path
+ * Return value:
+ *      a newly allocated string containing a relative path
+ * Description:
+ *      create a relative link
+ */
+gchar *create_relative_link_to(gchar * current_filepath, gchar * link_to_filepath)
 {
-	gtk_signal_handlers_destroy(GTK_OBJECT(windowname));
-	gtk_grab_remove(windowname);
-	gtk_widget_destroy(windowname);
+/* feature of this function: existing dir/../ are not removed,
+ but they should be removed! */
+
+	gchar *returnstring = NULL;
+	gchar *eff_current_filepath, *eff_link_to_filepath;
+	gint common_lenght, maxcommonlen;
+	gint current_filename_length, link_to_filename_length, current_dirname_length, link_to_dirname_length;
+	gint count, deeper_dirs;
+
+	if (!current_filepath){
+		returnstring = most_efficient_filename(g_strdup(link_to_filepath));
+		return returnstring;
+	}
+	if (!link_to_filepath) {
+		return NULL;
+	}
+	eff_current_filepath = most_efficient_filename(g_strdup(current_filepath));
+	eff_link_to_filepath = most_efficient_filename(g_strdup(link_to_filepath));
+
+	/* get the size of the directory    of the current_filename */
+
+	
+	current_filename_length = strlen(strrchr(eff_current_filepath, '/'))-1;
+	link_to_filename_length = strlen(strrchr(eff_link_to_filepath, '/'))-1;
+	DEBUG_MSG("create_relative_link_to, filenames: current: %d, link_to:%d\n", current_filename_length,link_to_filename_length); 
+	current_dirname_length = strlen(eff_current_filepath) - current_filename_length;
+	link_to_dirname_length = strlen(eff_link_to_filepath) - link_to_filename_length;
+	DEBUG_MSG("create_relative_link_to, dir's: current: %d, link_to:%d\n", current_dirname_length, link_to_dirname_length); 
+
+	if (current_dirname_length < link_to_dirname_length) {
+		maxcommonlen = current_dirname_length;
+	} else {
+		maxcommonlen = link_to_dirname_length;
+	}
+	
+	/* first lets get the common basedir for both dir+file  by comparing the
+	   common path in the directories */
+	common_lenght = 0;
+	while ((strncmp(eff_current_filepath, eff_link_to_filepath, common_lenght + 1)) == 0) {
+		common_lenght++;
+		if (common_lenght >= maxcommonlen) {
+			common_lenght = maxcommonlen;
+			break;
+		}
+	}
+	DEBUG_MSG("create_relative_link_to, common_lenght=%d\n", common_lenght);
+	/* now we need to count how much deeper (in directories) the current_filename
+	   is compared to the link_to_file, that is the amount of ../ we need to add */
+	deeper_dirs = 0;
+	for (count = common_lenght; count <= current_dirname_length; count++) {
+		if (eff_current_filepath[count] == '/') {
+			deeper_dirs++;
+			DEBUG_MSG("create_relative_link_to, on count=%d, deeper_dirs=%d\n", count, deeper_dirs);
+		}
+	}
+	DEBUG_MSG("create_relative_link_to, deeper_dirs=%d\n", deeper_dirs);
+
+	/* now we know everything we need to know we can create the relative link */
+	returnstring = g_malloc0(strlen(link_to_filepath) - common_lenght + 3 * deeper_dirs + 1);
+	count = deeper_dirs;
+	while (count) {
+		strcat(returnstring, "../");
+		count--;
+	}
+	strcat(returnstring, &eff_link_to_filepath[common_lenght]);
+	DEBUG_MSG("create_relative_link_to, returnstring=%s\n", returnstring);
+	g_free(eff_current_filepath);
+	g_free(eff_link_to_filepath);
+	return returnstring;
+}
+
+/*
+ * Function: create_full_path
+ * Arguments:
+ * 	filename: the relative filename
+ * 	basedir: a dir or file in the dir used as basedir for the filename
+ * 		if this is NULL the current working directory is used
+ * Return value:
+ *      a newly allocated string containing a absolute path
+ * Description:
+ *      create a absolute path
+ */
+gchar *create_full_path(gchar * filename, gchar *basedir)
+{
+	gchar *absolute_filename;
+	gchar *tmpcdir;
+
+	DEBUG_MSG("create_full_path, filename=%s, basedir=%p\n", filename, basedir);
+	if (g_path_is_absolute(filename)) {
+		absolute_filename = g_strdup(filename);
+	} else {
+		if (basedir) {
+			tmpcdir = g_dirname(basedir);
+		} else {
+			tmpcdir = g_get_current_dir();
+		}
+		absolute_filename = g_malloc0(strlen(tmpcdir) + strlen(filename) + 2);
+		absolute_filename = strcat(strcat(strcat(absolute_filename, tmpcdir), "/"), filename);
+		g_free(tmpcdir);
+	}
+	absolute_filename = most_efficient_filename(absolute_filename);
+	return absolute_filename;
 }
 
 gint file_exists_and_readable(gchar * filename)
@@ -381,9 +527,7 @@ static void modal_multiplefs_ok_clicked_lcb(GtkWidget * widget, gpointer data)
 	}
 	g_free(dirname);
 	gtk_main_quit();
-	gtk_grab_remove(GTK_WIDGET(data));
-	gtk_signal_handlers_destroy(data);
-	gtk_widget_destroy(GTK_WIDGET(data));
+	window_destroy(data);
 }
 
 
@@ -391,9 +535,7 @@ static void modal_fs_ok_clicked_lcb(GtkWidget * widget, gpointer window)
 {
 	filename_to_return = g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(window)));
 	gtk_main_quit();
-	gtk_grab_remove(GTK_WIDGET(window));
-	gtk_signal_handlers_destroy(window);
-	gtk_widget_destroy(GTK_WIDGET(window));
+	window_destroy(window);
 }
 
 static void close_modal_window_lcb(GtkWidget * widget, gpointer window)
@@ -403,7 +545,5 @@ static void close_modal_window_lcb(GtkWidget * widget, gpointer window)
 		filename_to_return = NULL;
 	}
 	gtk_main_quit();
-	gtk_grab_remove(GTK_WIDGET(window));
-	gtk_signal_handlers_destroy(window);
-	gtk_widget_destroy(GTK_WIDGET(window));
+	window_destroy(window);
 }
