@@ -24,14 +24,8 @@
 #include <glib.h>
 #include <gtk/gtkwidget.h>
 
-/* The current version !!!!!! */
-#define CURRENT_VERSION_NUMBER "0.3.6"
-/* don't remove the version number out of this name again
-   or I'll kill you.... ;-]
- */
-#define CURRENT_VERSION_NAME "Bluefish 0.3.6 HTML editor"
-/* You should probably edit configure_cb.in too, when you update the
-   version number. */
+/* needed to see if WITH_SPC is defined */
+#include "config.h"
 
 /* This is the type of each document */
 typedef struct {
@@ -47,7 +41,7 @@ typedef struct {
 	GtkWidget *tab_label;
 	gint highlightstate;
 	gint need_highlighting;		/* +1 means a '"' is added, +2 means a '<' is added, 4 means a '>' is added */
-} filestruct;
+} Tdocument;
 
 /* This is the current project */
 typedef struct {
@@ -64,7 +58,7 @@ typedef struct {
 	GList *classlist;
 	GList *metalist;
 	GList *filenames;
-} projectstruct;
+} Tproject;
 
 typedef struct {
 	gint v_html_tb;				/* view html toolbar */
@@ -83,16 +77,35 @@ typedef struct {
 	gint full_p;				/* use </p> */
 	gint full_li;				/* use </li> */
 	gint lowercase_tags;		/* use lowercase tags */
+	gint word_wrap;				/* use wordwrap */
+	gint line_wrap;				/* use line wrap */
+	gint fontset;				/* load fontset (0 = load font) */
+	gint link_management; 	/* perform link management */
+	gint defaulthighlight;		/* highlight documents by default */
+	gint cont_highlight_full; 	/* if you want to highlight the full text or just the line */
 	gint cont_highlight_update;	/* update the syntax highlighting continuous */
+	gchar *default_charset;
 	GList *external_filters;	/* external filter in list */
 	GList *external_commands;	/* external filter in list */
 	GList *syntax_configstrings;	/* the strings containing the colors and patters */
-} propertystruct;
+#ifdef WITH_SPC
+	/* spell checker options */
+	gchar *cfg_spc_cline      ;  /* spell checker command line */
+	gchar *cfg_spc_lang       ;  /* language */
+	gint  spc_accept_compound ;  /* accept compound words ? */
+	gint  spc_use_esc_chars   ;  /* specify aditional characters that
+                                     may be part of a word ? */
+	gchar* spc_esc_chars      ;  /* which ones ? */
+	gint   spc_use_pers_dict  ;  /* use a personal dictionary */
+	gchar* spc_pers_dict      ;  /* which one ? */                           
+#endif
+
+} Tproperties;
 
 typedef struct {
-	projectstruct current_project;
-	propertystruct props;
-	filestruct *current_document;	/* This is always the current visible one */
+	Tproject current_project;
+	Tproperties props;
+	Tdocument *current_document;	/* This is always the current visible one */
 	GList *documentlist;		/* The documents are now placed in a Glist */
 	GtkWidget *notebook;
 	gint last_notebook_page;	/* this is the last used, this can be used to track down if the notebook page really changed */
@@ -102,10 +115,9 @@ typedef struct {
 	GList *syntax_structs;		/* the props.syntax_configstrings parsed into structs with GdkColor and regex pattern */
 	GList *command_strings;
 	GList *filter_strings;
-	gshort fontset;
-} mainstruct;
+} Tmain;
 
-extern mainstruct *main_v;
+extern Tmain *main_v;
 
 /* for exiting bluefish */
 void cya_later(GtkWidget * widget, gpointer data);
@@ -121,8 +133,9 @@ char *strip_filename(gchar * string);
 
 /* strips the path that is common for both files */
 gchar *strip_common_path(char *image_fn, char *html_fn);
-void window_close(GtkWidget * button, gpointer windowname);
-
+gchar *most_efficient_filename(gchar *filename);
+gchar *create_relative_link_to(gchar * current_filepath, gchar * link_to_filepath);
+gchar *create_full_path(gchar * filename, gchar *basedir);
 /* returns 1 if the file is readable */
 gint file_exists_and_readable(gchar * filename);
 
