@@ -19,18 +19,14 @@
  */
 
 /* added dirty hack to prevent printf %x-stuff to be altered */
+#include "default_include.h"
 
 #include <ctype.h>
-#include <gtk/gtk.h>
 #include <string.h>
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
-#include "debug.h"
 #include "cap.h"
-#include "config.h"
 #include "bluefish.h"
 
 #define MAX_BUCKETS 7
