@@ -22,24 +22,20 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. 
  *
  */
+#include "default_include.h"
 
 #include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <gtk/gtk.h>
 #include <gtk/gtkhbbox.h>
-
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
-#include "config.h"
 #include "coloursel.h"
+#include "interface.h"
 #include "cap.h"
 #include "gtk_easy.h"
 #include "bluefish.h"
-#include "interface.h"
-#include "debug.h"
+#include "document.h"			/* insert_text */
 
 /*  
  * If you change the way the color values are stored,
@@ -427,8 +423,8 @@ static void gtk_color_selection_init(GtkColorSelection * colorsel)
 
 		colorsel->entries[n] = gtk_entry_new();
 		gtk_widget_set_usize(colorsel->entries[n], 40, 0);
-    if (n != SATURATION) {
-		  DEBUG_MSG("saturation detected\n");
+		if (n != SATURATION) {
+			DEBUG_MSG("saturation detected\n");
 			sprintf(txt, "%.0f", colorsel->values[n]);
 		} else {
 			sprintf(txt, "%.2f", colorsel->values[n]);
@@ -615,7 +611,7 @@ static void gtk_color_selection_update_input(GtkWidget * scale, GtkWidget * entr
 {
 	GtkAdjustment *adj;
 	gchar txt[32];
-  DEBUG_MSG("ui entry=%p, val=%f\n",entry,value);
+	DEBUG_MSG("ui entry=%p, val=%f\n", entry, value);
 	if (scale != NULL) {
 		adj = gtk_range_get_adjustment(GTK_RANGE(scale));
 		adj->value = (gfloat) value;
@@ -626,7 +622,7 @@ static void gtk_color_selection_update_input(GtkWidget * scale, GtkWidget * entr
 	}
 	if (entry != NULL) {
 		gtk_signal_handler_block_by_data(GTK_OBJECT(entry), (gpointer) entry);
-			sprintf(txt, "%.0f", value);
+		sprintf(txt, "%.0f", value);
 		gtk_entry_set_text(GTK_ENTRY(entry), txt);
 		gtk_signal_handler_unblock_by_data(GTK_OBJECT(entry), (gpointer) entry);
 	}
@@ -636,7 +632,7 @@ static void gtk_color_selection_update_saturation_input(GtkWidget * scale, GtkWi
 {
 	GtkAdjustment *adj;
 	gchar txt[32];
-  DEBUG_MSG("ui saturation entry=%p, val=%f\n",entry,value);
+	DEBUG_MSG("ui saturation entry=%p, val=%f\n", entry, value);
 	if (scale != NULL) {
 		adj = gtk_range_get_adjustment(GTK_RANGE(scale));
 		adj->value = (gfloat) value;
@@ -647,7 +643,7 @@ static void gtk_color_selection_update_saturation_input(GtkWidget * scale, GtkWi
 	}
 	if (entry != NULL) {
 		gtk_signal_handler_block_by_data(GTK_OBJECT(entry), (gpointer) entry);
-			sprintf(txt, "%.2f", value);
+		sprintf(txt, "%.2f", value);
 		gtk_entry_set_text(GTK_ENTRY(entry), txt);
 		gtk_signal_handler_unblock_by_data(GTK_OBJECT(entry), (gpointer) entry);
 	}
@@ -685,7 +681,7 @@ static void gtk_color_selection_update_inputs(GtkColorSelection * colorsel, gint
 				if (n != SATURATION) {
 					gtk_color_selection_update_input(NULL, colorsel->entries[n], colorsel->values[n]);
 				} else {
-				gtk_color_selection_update_saturation_input(NULL, colorsel->entries[n], colorsel->values[n]);
+					gtk_color_selection_update_saturation_input(NULL, colorsel->entries[n], colorsel->values[n]);
 				}
 			}
 		}
@@ -913,7 +909,7 @@ static void gtk_color_selection_draw_value_marker(GtkColorSelection * colorsel)
 static void gtk_color_selection_update_value(GtkColorSelection * colorsel, gint y)
 {
 	gtk_color_selection_draw_value_marker(colorsel);
-	DEBUG_MSG("upd_value=%d\n",y);
+	DEBUG_MSG("upd_value=%d\n", y);
 
 	if (y < 0)
 		y = 0;
@@ -1285,7 +1281,7 @@ static void gtk_color_selection_hsv_to_rgb(gdouble h, gdouble s, gdouble v, gdou
 {
 	gint i;
 	gdouble f, w, q, t;
-  
+
 	if (s == 0.0)
 		s = 0.000001;
 
