@@ -18,31 +18,32 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <gtk/gtk.h>
+#include "default_include.h"
+
 #include <string.h>
-
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
-#include "config.h"
 #include "bluefish.h"
 #include "init.h"
 #include "gtk_easy.h"
 #include "menu.h"
-#include "debug.h"
 #include "interface.h"
-#include "stringlist.h"
 #include "highlight.h"
+#include "document.h"			/* set fonts */
+
+typedef enum { none, file, font } Textra_but;
 
 GtkWidget *font_e, *browser_e, *weblint_e, *tabfont_e, *tabpos_c;
 GtkWidget *width_s, *height_s, *tab_s, *thumbtype_c, *thumbstring_e;
-GtkWidget *full_li_c, *full_p_c, *lowercase_tags_c;
-GtkWidget *cont_high_up_c;
+GtkWidget *full_li_c, *full_p_c, *lowercase_tags_c, *word_wrap_c, *line_wrap_c, *fontset_c, *link_management_c, *defaulthighlight_c;
+GtkWidget *cont_high_up_c, *cont_highlight_full_c, *default_charset_c;
+
+#ifdef WITH_SPC
+GtkWidget *spc_command_e, *spc_lang_e, *spc_acc_comp_c, *spc_use_esc_c, *spc_use_pers_dict_c, *spc_pers_dict_e;
+#endif
 
 /**************************************************************************/
 void configure_cb(GtkWidget * widget, gpointer data);
-static GtkWidget *string_entry2(gchar * labeltext, gchar * which_config_string, GtkWidget * box);
 static GtkWidget *combo_entry2(gchar * labeltext, gchar * which_config_string, GtkWidget * box, GList * poplist);
 static GtkWidget *check_entry2(gchar * labeltext, gint which_config_int, GtkWidget * box);
 static void apply_choose_font(GtkWidget * widget, gpointer data);
@@ -50,11 +51,8 @@ static void ok_choose_font(GtkWidget * widget, gpointer data);
 static void delete_choose_font(GtkWidget * widget, GdkEventAny * event, gpointer data);
 static void close_choose_font(GtkWidget * widget, gpointer data);
 static void choose_font(GtkWidget * widget, gpointer data);
-static void reset_syntax_highlighting_lcb(GtkWidget * widget, gpointer data);
-static void get_configure_menu(GtkWidget * window, GtkWidget ** menubar);
 static void integer_apply(gint * config_var, GtkWidget * spinbutton);
 static void check_apply(gint * config_var, GtkWidget * check_button);
-static void apply_config(GtkWidget * button, gpointer entry);
 
 /**************************************************************************/
 
@@ -64,42 +62,61 @@ static void apply_config(GtkWidget * button, gpointer entry);
  *
  *************************/
 
-static GtkWidget *string_entry2(gchar * labeltext, gchar * which_config_string, GtkWidget * box)
+static GtkWidget *string_entry2(gchar * labeltext, gchar * which_config_string, GtkWidget * box, Textra_but with_but)
 {
+	GtkWidget *hbox, *return_widget, *font_b=NULL;
 
-	GtkWidget *return_widget;
-
-	return_widget = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(return_widget), which_config_string);
-	gtk_box_pack_start(GTK_BOX(box), gtk_label_new(labeltext), FALSE, FALSE, 3);
-	gtk_box_pack_start(GTK_BOX(box), return_widget, TRUE, TRUE, 3);
+	hbox = gtk_hbox_new(FALSE,3);
+	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(labeltext), FALSE, FALSE, 3);
+	return_widget = boxed_entry_with_text(which_config_string, 1023, hbox);
+	gtk_box_pack_start(GTK_BOX(box), hbox, FALSE, FALSE, 3);
+	if (with_but == file) {
+		gtk_box_pack_start(GTK_BOX(hbox), file_but_new(return_widget, gtk_widget_get_toplevel(box), 1), FALSE, FALSE, 3);
+	} else if (with_but == font) {
+		font_b = gtk_button_new_with_label(_("Font..."));
+		gtk_signal_connect(GTK_OBJECT(font_b), "clicked", GTK_SIGNAL_FUNC(choose_font), return_widget);
+		gtk_box_pack_start(GTK_BOX(hbox), font_b, FALSE, FALSE, 0);
+	}
 	return return_widget;
 }
 
 static GtkWidget *combo_entry2(gchar * labeltext, gchar * which_config_string, GtkWidget * box, GList * poplist)
 {
+	GtkWidget *return_widget;
+	GtkWidget *hbox;
 
-	GtkWidget *label, *return_widget;
-
-	label = gtk_label_new(labeltext);
-	return_widget = gtk_combo_new();
-	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(return_widget)->entry), FALSE);
-	gtk_combo_set_popdown_strings(GTK_COMBO(return_widget), poplist);
-	g_list_free(poplist);
-
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(return_widget)->entry), which_config_string);
-	gtk_box_pack_start(GTK_BOX(box), label, FALSE, FALSE, 3);
-	gtk_box_pack_start(GTK_BOX(box), return_widget, FALSE, FALSE, 3);
+	hbox = gtk_hbox_new(FALSE,3);
+	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(labeltext), FALSE, FALSE, 3);
+	return_widget = boxed_combo_with_popdown(which_config_string, poplist, 0, hbox);
+	gtk_box_pack_start(GTK_BOX(box), hbox, FALSE, FALSE, 3);
 	return return_widget;
 }
 
 static GtkWidget *check_entry2(gchar * labeltext, gint which_config_int, GtkWidget * box)
 {
-	GtkWidget *return_widget;
+	return boxed_checkbut_with_value(labeltext, which_config_int, box);
+}
 
-	return_widget = gtk_check_button_new_with_label(labeltext);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(return_widget), which_config_int);
-	gtk_box_pack_start(GTK_BOX(box), return_widget, FALSE, FALSE, 3);
+static GtkWidget *spin_button2(gchar *labeltext, gint which_config_int, GtkWidget * box, gfloat lower, gfloat upper) {
+	GtkWidget *return_widget;
+	GtkWidget *hbox;
+	GtkObject *adjust;
+	gfloat step_increment, page_increment;
+
+	step_increment = (upper - lower)/1000;
+	if (step_increment < 1) {
+		step_increment = 1;
+	}
+	page_increment = (upper - lower)/20;
+	if (page_increment < 10) {
+		page_increment = 10;
+	}
+	hbox = gtk_hbox_new(FALSE,3);
+	adjust = gtk_adjustment_new((1.0 * which_config_int), lower, upper, step_increment ,page_increment , 0);
+	return_widget = gtk_spin_button_new(GTK_ADJUSTMENT(adjust), 0.1, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(labeltext), FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(hbox), return_widget, TRUE, TRUE, 3);
+	gtk_box_pack_start(GTK_BOX(box), hbox, FALSE, FALSE, 3);
 	return return_widget;
 }
 
@@ -108,38 +125,37 @@ static GtkWidget *check_entry2(gchar * labeltext, gint which_config_int, GtkWidg
 static void apply_choose_font(GtkWidget * widget, gpointer data)
 {
 	gchar *font;
-	font = gtk_font_selection_dialog_get_font_name(GTK_FONT_SELECTION_DIALOG(data));
-	DEBUG_MSG("font=%s\n", font);
-	/* FIXME: emit signal to entry here or not? */
-	gtk_entry_set_text(GTK_ENTRY(font_e), font);
-	/* this shouldn't be free-ed !!!!!
-	   g_free (font); */
+	GtkWidget *font_dialog;
+
+	font_dialog = gtk_widget_get_toplevel(widget);
+	font = gtk_font_selection_dialog_get_font_name(GTK_FONT_SELECTION_DIALOG(font_dialog));
+	DEBUG_MSG("apply_choose_font, font=%s\n", font);
+	gtk_entry_set_text(GTK_ENTRY(data), font);
 };
 
 /*
  */
 static void ok_choose_font(GtkWidget * widget, gpointer data)
 {
-	/* FIXME: Or more rigth ue any emit* function */
 	apply_choose_font(widget, data);
-	gtk_grab_remove(GTK_WIDGET(data));
-	gtk_widget_destroy(GTK_WIDGET(data));
+	delete_choose_font(widget, NULL, data);
 };
 
 /*
  */
 static void delete_choose_font(GtkWidget * widget, GdkEventAny * event, gpointer data)
 {
-	DEBUG_MSG("data=%p\n", data);
-	gtk_grab_remove(GTK_WIDGET(data));
-	gtk_widget_destroy(GTK_WIDGET(data));
+	GtkWidget *win;
+	DEBUG_MSG("delete_choose_font, data=%p\n", data);
+	win = gtk_widget_get_toplevel(widget);
+	gtk_grab_remove(GTK_WIDGET(win));
+	gtk_widget_destroy(GTK_WIDGET(win));
 };
 
 /*
  */
 static void close_choose_font(GtkWidget * widget, gpointer data)
 {
-	/* FIXME: Or more right use any emit* function? */
 	delete_choose_font(widget, NULL, data);
 };
 
@@ -162,21 +178,21 @@ static void choose_font(GtkWidget * widget, gpointer data)
 	font_dialog = gtk_font_selection_dialog_new(_("Font Selection"));
 
 	/* Set font in font selection dialog */
-	font = gtk_entry_get_text(GTK_ENTRY(data));
+	font = gtk_editable_get_chars(GTK_EDITABLE(data), 0, -1);
 	gtk_font_selection_dialog_set_font_name(GTK_FONT_SELECTION_DIALOG(font_dialog), font);
 	g_free(font);
 
 	/* connect all needing signals */
 	gtk_signal_connect(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(font_dialog)->ok_button),
-					   "clicked", GTK_SIGNAL_FUNC(ok_choose_font), (gpointer) font_dialog);
+					   "clicked", GTK_SIGNAL_FUNC(ok_choose_font), (gpointer) data);
 
 	gtk_signal_connect(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(font_dialog)->apply_button),
-					   "clicked", GTK_SIGNAL_FUNC(apply_choose_font), (gpointer) font_dialog);
+					   "clicked", GTK_SIGNAL_FUNC(apply_choose_font), (gpointer) data);
 
 	gtk_signal_connect(GTK_OBJECT(GTK_FONT_SELECTION_DIALOG(font_dialog)->cancel_button),
-					   "clicked", GTK_SIGNAL_FUNC(close_choose_font), (gpointer) font_dialog);
+					   "clicked", GTK_SIGNAL_FUNC(close_choose_font), (gpointer) data);
 
-	gtk_signal_connect(GTK_OBJECT(font_dialog), "delete_event", GTK_SIGNAL_FUNC(delete_choose_font), (gpointer) font_dialog);
+	gtk_signal_connect(GTK_OBJECT(font_dialog), "delete_event", GTK_SIGNAL_FUNC(delete_choose_font), (gpointer) data);
 
 	DEBUG_MSG("font_dialog=%p\n", font_dialog);
 	gtk_widget_show_all(font_dialog);
@@ -185,98 +201,99 @@ static void choose_font(GtkWidget * widget, gpointer data)
 	gtk_grab_add(font_dialog);
 };
 
-static void reset_syntax_highlighting_lcb(GtkWidget * widget, gpointer data)
+
+static void save_n_apply_config()
 {
-	free_stringlist(main_v->props.syntax_configstrings);
-	main_v->props.syntax_configstrings = NULL;
+	GList *tmplist;
+	Tdocument *tmpdoc;
 
-	main_v->props.syntax_configstrings = add_to_stringlist(main_v->props.syntax_configstrings, "#000080 <[^(!|%|?)][^>]*>");
-	main_v->props.syntax_configstrings = add_to_stringlist(main_v->props.syntax_configstrings, "#ee0000 (<\\\?)[^?]*(\\\?>)");
-	main_v->props.syntax_configstrings = add_to_stringlist(main_v->props.syntax_configstrings, "#ee0000 (<\\\?)[^>]*(\\\?>)");
-	main_v->props.syntax_configstrings = add_to_stringlist(main_v->props.syntax_configstrings, "#bd0000 (<[/]*script[^>]*>)");
-	main_v->props.syntax_configstrings =
-		add_to_stringlist(main_v->props.syntax_configstrings, "#00AAAA (<[/]*table[^>]*>)|(<[/]*td[^>]*>)|(<[/]*tr[^>]*>)|(<[/]*th[^>]*>)");
-	main_v->props.syntax_configstrings =
-		add_to_stringlist(main_v->props.syntax_configstrings,
-						  "#4080bf (<[/]*form[^>]*>)|(<input[^>]*>)|(<[/]*select[^>]*>)|(<[/]*textarea[^>]*>)|(<[/]*option[^>]*>)");
-	main_v->props.syntax_configstrings = add_to_stringlist(main_v->props.syntax_configstrings, "#eead0e (<[/]*a[^>]*>)|(<[/]*img[^>]*>)");
-	main_v->props.syntax_configstrings = add_to_stringlist(main_v->props.syntax_configstrings, "#969696 (<!--)[^>]*-->");
-	main_v->props.syntax_configstrings = add_to_stringlist(main_v->props.syntax_configstrings, "#22AA00 \"[^\"]*\"");
-}
-
-static void edit_some_list_lcb(GtkWidget * widget, gpointer data)
-{
-	switch (GPOINTER_TO_INT(data)) {
-#ifdef DEVELOPMENT
-	case 1:
-		main_v->props.external_filters = edit_stringlist(main_v->props.external_filters, _("Bluefish configuration - external filters"), 7);
-		break;
-#endif
-	case 2:
-		main_v->props.external_commands =
-			edit_stringlist(main_v->props.external_commands, _("Bluefish configuration - external commands"), 7);
-		break;
-	case 3:
-		main_v->props.syntax_configstrings =
-			edit_stringlist(main_v->props.syntax_configstrings, _("Bluefish configuration - syntax highlighting"), 8);
-		break;
-	default:
-
-		break;
+	save_config_files();
+	
+	/* actually try to apply these config values */
+	gtk_window_set_policy(GTK_WINDOW(main_v->main_window), FALSE, FALSE, FALSE);
+	gtk_widget_set_usize(GTK_WIDGET(main_v->main_window), main_v->props.main_window_w, main_v->props.main_window_h);
+	gtk_window_set_policy(GTK_WINDOW(main_v->main_window), TRUE, TRUE, FALSE);
+	tmplist = g_list_first(main_v->documentlist);
+	while (tmplist) {
+		tmpdoc = (Tdocument *) tmplist->data;
+		if (tmpdoc) {
+			document_set_fonts(main_v->props.cfg_editor_font, main_v->props.cfg_tab_font, tmpdoc);
+			document_set_wrap(main_v->props.word_wrap, main_v->props.line_wrap, tmpdoc);
+			GTK_TEXT(tmpdoc->textbox)->default_tab_width = main_v->props.cfg_editor_tabwidth;
+		}						/* if (tmpdoc) */
+		tmplist = g_list_next(tmplist);
 	}
+	notebook_set_tab_pos(main_v->props.cfg_tab_pos);
+	make_syntax_struct_list();
+	make_external_menu_entries(1);
+	make_external_menu_entries(2);
+
+	statusbar_message(_("Configuration saved and applied succesfully"), 1000);
+	DEBUG_MSG("apply_config, finished applying config values\n");
 }
 
-static GtkItemFactoryEntry menu_items[] = {
-	{N_("/_Lists"), NULL, NULL, 0, "<Branch>"},
-#ifdef DEVELOPMENT
-	{N_("/Lists/External filters"), NULL, edit_some_list_lcb, 1, NULL},
+
+static void configure_ok_lcb(GtkWidget * button, gpointer entry) {
+
+	statusbar_message(_("Saving and applying configuration"), 1000);
+	string_apply(&main_v->props.cfg_browser_cline, browser_e);
+	string_apply(&main_v->props.cfg_weblint_cline, weblint_e);
+	string_apply(&main_v->props.cfg_editor_font, font_e);
+	string_apply(&main_v->props.cfg_tab_font, tabfont_e);
+	string_apply(&main_v->props.cfg_tab_pos, GTK_COMBO(tabpos_c)->entry);
+	string_apply(&main_v->props.cfg_thumbnailtype, GTK_COMBO(thumbtype_c)->entry);
+	string_apply(&main_v->props.cfg_thumbnailstring, thumbstring_e);
+	integer_apply(&main_v->props.main_window_w, width_s);
+	integer_apply(&main_v->props.main_window_h, height_s);
+	integer_apply(&main_v->props.cfg_editor_tabwidth, tab_s);
+	check_apply(&main_v->props.full_p, full_p_c);
+	check_apply(&main_v->props.full_li, full_li_c);
+	check_apply(&main_v->props.word_wrap, word_wrap_c);
+	check_apply(&main_v->props.line_wrap, line_wrap_c);
+	check_apply(&main_v->props.fontset, fontset_c);
+	check_apply(&main_v->props.link_management, link_management_c);
+	check_apply(&main_v->props.defaulthighlight, defaulthighlight_c);
+	check_apply(&main_v->props.lowercase_tags, lowercase_tags_c);
+	check_apply(&main_v->props.cont_highlight_update, cont_high_up_c);
+	check_apply(&main_v->props.cont_highlight_full, cont_highlight_full_c);
+	string_apply(&main_v->props.default_charset, GTK_COMBO(default_charset_c)->entry);
+#ifdef WITH_SPC
+	string_apply(&main_v->props.cfg_spc_cline, spc_command_e);
+	string_apply(&main_v->props.cfg_spc_lang, spc_lang_e);
+	check_apply(&main_v->props.spc_accept_compound, spc_acc_comp_c);
+	check_apply(&main_v->props.spc_use_esc_chars, spc_use_esc_c);
+	check_apply(&main_v->props.spc_use_pers_dict, spc_use_pers_dict_c);
+	string_apply(&main_v->props.spc_pers_dict, spc_pers_dict_e);
 #endif
-	{N_("/Lists/External programs"), NULL, edit_some_list_lcb, 2, NULL},
-	{N_("/Lists/Syntax highlighting"), NULL, edit_some_list_lcb, 3, NULL},
-	{N_("/Lists/Reset syntax highlighting"), NULL, reset_syntax_highlighting_lcb, 0, NULL}
-};
+	if (main_v->props.syntax_configstrings == NULL) {
+		reset_syntax_highlighting_lcb(NULL, NULL);
+	}
+	gtk_main_quit();
 
-static void get_configure_menu(GtkWidget * window, GtkWidget ** menubar)
-{
-	GtkItemFactory *item_factory;
-	GtkAccelGroup *accel_group;
-	gint nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
-
-	accel_group = gtk_accel_group_new();
-	item_factory = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>", accel_group);
-	gtk_item_factory_set_translate_func(item_factory, menu_translate, "<main>", NULL);
-	gtk_item_factory_create_items(item_factory, nmenu_items, menu_items, NULL);
-	gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);
-	if (menubar)
-		*menubar = gtk_item_factory_get_widget(item_factory, "<main>");
+	save_n_apply_config();
 }
 
+
+
+
 void configure_cb(GtkWidget * widget, gpointer data)
 {
-	/* This is the callback function for a configure_cb button */
-
-	/* This configuration dialog is simplistic and will probably need
-	   a rewrite. */
-
-	/* declare the widgets */
-	GtkWidget *frame, *menubar, *dialog;
+	GtkWidget *frame, *dialog;
 	GtkWidget *ok;
 	GtkWidget *cancel;
-	GtkWidget *vbox, *hbox;
+	GtkWidget *vbox;
 	GtkWidget *notebook;
-	GtkWidget *font_b;
-	GtkObject *adjust;
 	GList *poplist = NULL;
+	gint count;
 
 	/* create the widgets */
 	DEBUG_MSG("configure_cb, started\n");
+	count = bf_statusbar_message(_("Configuration Window"));
 	dialog = gtk_dialog_new();
 	gtk_signal_connect(GTK_OBJECT(dialog), "delete_event", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog), "destroy", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 	/* give the dialog a name */
-	gtk_window_set_title(GTK_WINDOW(dialog), _("Bluefish configuration"));
-	get_configure_menu(dialog, &menubar);
-	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->vbox), menubar, TRUE, TRUE, 0);
+	gtk_widget_realize(dialog);
 
 	notebook = gtk_notebook_new();
 	gtk_notebook_set_homogeneous_tabs(GTK_NOTEBOOK(notebook), TRUE);
@@ -287,29 +304,58 @@ void configure_cb(GtkWidget * widget, gpointer data)
 	frame = gtk_frame_new(_("Editor options"));
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
-	hbox = gtk_hbox_new(FALSE, 0);
-	font_e = string_entry2(_("Default fontset"), main_v->props.cfg_editor_font, hbox);
-	font_b = gtk_button_new_with_label(_("Fontset..."));
-	gtk_signal_connect(GTK_OBJECT(font_b), "clicked", GTK_SIGNAL_FUNC(choose_font), font_e);
-	gtk_box_pack_start(GTK_BOX(hbox), font_b, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 3);
 
-	adjust = gtk_adjustment_new(1.0 * main_v->props.cfg_editor_tabwidth, 1, 20, 1, 1, 0);
-	tab_s = gtk_spin_button_new(GTK_ADJUSTMENT(adjust), 0.1, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), gtk_label_new(_("Tab width")), FALSE, FALSE, 3);
-	gtk_box_pack_start(GTK_BOX(vbox), tab_s, FALSE, FALSE, 3);
+	font_e = string_entry2(_("Default font"), main_v->props.cfg_editor_font, vbox, font);
+
+	tab_s = spin_button2(_("Tab width"), main_v->props.cfg_editor_tabwidth, vbox, 1.0, 20.0);
+
+	word_wrap_c = check_entry2(_("Word wrap"), main_v->props.word_wrap, vbox);
+	line_wrap_c = check_entry2(_("Line wrap"), main_v->props.line_wrap, vbox);
+	defaulthighlight_c = check_entry2(_("Highlight by default"), main_v->props.defaulthighlight, vbox);
+	cont_high_up_c = check_entry2(_("Update syntax highlighting continuous"), main_v->props.cont_highlight_update, vbox);
+	cont_highlight_full_c = check_entry2(_("Update full widget instead of the current line (slower)"), main_v->props.cont_highlight_full, vbox);
+	link_management_c = check_entry2(_("Automatic link management"), main_v->props.link_management, vbox);
+
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new(_("Editor")));
+	/* HTML options */
+	frame = gtk_frame_new(_("HTML options"));
+	vbox = gtk_vbox_new(FALSE, 0);
+	gtk_container_add(GTK_CONTAINER(frame), vbox);
+
 	full_li_c = check_entry2(_("Insert closing list-item tag </LI>"), main_v->props.full_li, vbox);
 	full_p_c = check_entry2(_("Insert closing paragraph tag </P>"), main_v->props.full_p, vbox);
-	cont_high_up_c = check_entry2(_("Update syntax highlighting continuous"), main_v->props.cont_highlight_update, vbox);
-	lowercase_tags_c = check_entry2(_("Insert lowercase HTML tags"), main_v->props.lowercase_tags, vbox);
-	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new(_("Editor")));
+	lowercase_tags_c = check_entry2(_("Insert lowercase HTML tags (Needed for WML!)"), main_v->props.lowercase_tags, vbox);
+
+	poplist = NULL;
+	poplist = g_list_append(poplist, "other");
+	poplist = g_list_append(poplist, "iso8859-1");
+	poplist = g_list_append(poplist, "iso8859-2");
+	poplist = g_list_append(poplist, "iso8859-3");
+	poplist = g_list_append(poplist, "iso8859-4");
+	poplist = g_list_append(poplist, "iso8859-5");
+	poplist = g_list_append(poplist, "iso8859-6");
+	poplist = g_list_append(poplist, "iso8859-7");
+	poplist = g_list_append(poplist, "iso8859-8");
+	poplist = g_list_append(poplist, "iso8859-9");
+	poplist = g_list_append(poplist, "iso8859-10");
+	poplist = g_list_append(poplist, "iso8859-11");
+	poplist = g_list_append(poplist, "iso8859-12");
+	poplist = g_list_append(poplist, "iso8859-13");
+	poplist = g_list_append(poplist, "iso8859-14");
+	poplist = g_list_append(poplist, "iso8859-15");
+
+	default_charset_c = combo_entry2(_("Default charset"), main_v->props.default_charset, vbox, poplist);
+	g_list_free(poplist);
+
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new(_("HTML")));
 
 	/* main GUI */
 	frame = gtk_frame_new(_("Main GUI options"));
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
-	tabfont_e = string_entry2(_("Notebook tab fontset"), main_v->props.cfg_tab_font, vbox);
+	tabfont_e = string_entry2(_("Notebook tab fontset"), main_v->props.cfg_tab_font, vbox, font);
+	fontset_c = check_entry2(_("Font is a fontset"), main_v->props.fontset, vbox);
 
 	poplist = NULL;
 	poplist = g_list_append(poplist, "top");
@@ -318,16 +364,10 @@ void configure_cb(GtkWidget * widget, gpointer data)
 	poplist = g_list_append(poplist, "right");
 
 	tabpos_c = combo_entry2(_("Notebook position"), main_v->props.cfg_tab_pos, vbox, poplist);
+	g_list_free(poplist);
 
-	adjust = gtk_adjustment_new(1.0 * main_v->props.main_window_w, 50, 2000, 5, 25, 0);
-	width_s = gtk_spin_button_new(GTK_ADJUSTMENT(adjust), 0.1, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), gtk_label_new(_("Initial width")), FALSE, FALSE, 3);
-	gtk_box_pack_start(GTK_BOX(vbox), width_s, FALSE, FALSE, 3);
-
-	adjust = gtk_adjustment_new(1.0 * main_v->props.main_window_h, 50, 2000, 5, 25, 0);
-	height_s = gtk_spin_button_new(GTK_ADJUSTMENT(adjust), 0.1, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), gtk_label_new(_("Initial height")), FALSE, FALSE, 3);
-	gtk_box_pack_start(GTK_BOX(vbox), height_s, FALSE, FALSE, 3);
+	width_s = spin_button2(_("Initial width"), main_v->props.main_window_w, vbox, 50.0, 2000.0);
+	height_s = spin_button2(_("Initial height"), main_v->props.main_window_h, vbox, 50.0, 2000.0);
 
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new(_("GUI")));
 
@@ -341,8 +381,9 @@ void configure_cb(GtkWidget * widget, gpointer data)
 	poplist = g_list_append(poplist, "jpg");
 	poplist = g_list_append(poplist, "gif");
 	thumbtype_c = combo_entry2(_("Thumbnail type"), main_v->props.cfg_thumbnailtype, vbox, poplist);
+	g_list_free(poplist);
 
-	thumbstring_e = string_entry2(_("Thumbnail extension string"), main_v->props.cfg_thumbnailstring, vbox);
+	thumbstring_e = string_entry2(_("Thumbnail extension string"), main_v->props.cfg_thumbnailstring, vbox, none);
 
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new(_("Image dialog")));
 
@@ -351,15 +392,21 @@ void configure_cb(GtkWidget * widget, gpointer data)
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
 
-	browser_e = string_entry2(_("Browser command"), main_v->props.cfg_browser_cline, vbox);
-	weblint_e = string_entry2(_("Weblint command"), main_v->props.cfg_weblint_cline, vbox);
-
+	browser_e = string_entry2(_("Browser command"), main_v->props.cfg_browser_cline, vbox, file);
+	weblint_e = string_entry2(_("Weblint command"), main_v->props.cfg_weblint_cline, vbox, file);
+#ifdef WITH_SPC
+	spc_command_e = string_entry2(_("Ispell command"), main_v->props.cfg_spc_cline, vbox, file );
+	spc_lang_e = string_entry2(_("Default language"), main_v->props.cfg_spc_lang, vbox, none);
+	spc_acc_comp_c = check_entry2(_("Accept compound words"), main_v->props.spc_accept_compound, vbox);
+	spc_use_esc_c = check_entry2(_("Specify additional characters that might form a word"), main_v->props.spc_use_esc_chars, vbox);
+	spc_use_pers_dict_c = check_entry2(_("Use personal dictionary"), main_v->props.spc_use_pers_dict, vbox);
+	spc_pers_dict_e = string_entry2(_("Personal dictionary"), main_v->props.spc_pers_dict, vbox, file);
+#endif
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), frame, gtk_label_new(_("External")));
 
-	ok = bf_stock_button(_(" Save & close "), GTK_SIGNAL_FUNC(apply_config), dialog);
+	ok = bf_stock_button(_(" Save & close "), GTK_SIGNAL_FUNC(configure_ok_lcb), dialog);
 	cancel = bf_stock_cancel_button(GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
 
-
 	/* pack the widgets */
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dialog)->action_area), ok, TRUE, TRUE, 0);
 	gtk_box_pack_end(GTK_BOX(GTK_DIALOG(dialog)->action_area), cancel, TRUE, TRUE, 0);
@@ -369,11 +416,9 @@ void configure_cb(GtkWidget * widget, gpointer data)
 
 	gtk_grab_add(dialog);
 	gtk_main();
-	gtk_grab_remove(dialog);
-
-	gtk_object_destroy(GTK_OBJECT(dialog));
-
-	gtk_main();
+	DEBUG_MSG("configure_cb, just after gtk_main()\n");
+  	statusbar_remove(GINT_TO_POINTER(count));
+	window_destroy(dialog);
 }
 
 static void integer_apply(gint * config_var, GtkWidget * spinbutton)
@@ -392,50 +437,3 @@ static void check_apply(gint * config_var, GtkWidget * check_button)
 	}
 }
 
-static void apply_config(GtkWidget * button, gpointer entry)
-{
-	GList *tmplist;
-	filestruct *tmpdoc;
-
-	statusbar_message(_("Saving and applying configuration"), 1000);
-	string_apply(&main_v->props.cfg_browser_cline, browser_e);
-	string_apply(&main_v->props.cfg_weblint_cline, weblint_e);
-	string_apply(&main_v->props.cfg_editor_font, font_e);
-	string_apply(&main_v->props.cfg_tab_font, tabfont_e);
-	string_apply(&main_v->props.cfg_tab_pos, GTK_COMBO(tabpos_c)->entry);
-	string_apply(&main_v->props.cfg_thumbnailtype, GTK_COMBO(thumbtype_c)->entry);
-	string_apply(&main_v->props.cfg_thumbnailstring, thumbstring_e);
-	integer_apply(&main_v->props.main_window_w, width_s);
-	integer_apply(&main_v->props.main_window_h, height_s);
-	integer_apply(&main_v->props.cfg_editor_tabwidth, tab_s);
-	check_apply(&main_v->props.full_p, full_p_c);
-	check_apply(&main_v->props.full_li, full_li_c);
-	check_apply(&main_v->props.lowercase_tags, lowercase_tags_c);
-	check_apply(&main_v->props.cont_highlight_update, cont_high_up_c);
-	if (main_v->props.syntax_configstrings == NULL) {
-		reset_syntax_highlighting_lcb(NULL, NULL);
-	}
-	gtk_main_quit();
-	save_config_files();
-
-	/* actually try to apply these config values */
-	gtk_window_set_policy(GTK_WINDOW(main_v->main_window), FALSE, FALSE, FALSE);
-	gtk_widget_set_usize(GTK_WIDGET(main_v->main_window), main_v->props.main_window_w, main_v->props.main_window_h);
-	gtk_window_set_policy(GTK_WINDOW(main_v->main_window), TRUE, TRUE, FALSE);
-	tmplist = g_list_first(main_v->documentlist);
-	while (tmplist) {
-		tmpdoc = (filestruct *) tmplist->data;
-		if (tmpdoc) {
-			document_set_fonts(main_v->props.cfg_editor_font,main_v->props.cfg_tab_font,tmpdoc );
-			GTK_TEXT(tmpdoc->textbox)->default_tab_width = main_v->props.cfg_editor_tabwidth;
-		}						/* if (tmpdoc) */
-		tmplist = g_list_next(tmplist);
-	}
-	notebook_set_tab_pos(main_v->props.cfg_tab_pos);
-	make_syntax_struct_list();
-	make_external_menu_entries(1);
-	make_external_menu_entries(2);
-
-	statusbar_message(N_("Configuration saved and applied succesfully"), 1000);
-	DEBUG_MSG("apply_config, finished applying config values\n");
-}
