@@ -38,6 +38,18 @@ typedef struct {
 	gint len;
 } Treplacerange;
 
+extern GtkWidget *dialog, *vbox, *hbox, *okbutton, *cancelbutton, *label, *dialogtable;
+extern GtkWidget *textentry1, *textentry2, *textentry3, *textentry4, *spin1, *spin2;
+extern GtkWidget *scrollbar, *checkbox1, *checkbox2, *radio1, *radio2, *spin3, *spin4;
+extern GtkWidget *radio0, *radio3, *radio4, *radio5, *radio6, *radio7, *radio8, *radio9, *box;
+extern GtkWidget *frame1, *frame2;
+extern GtkWidget *combo1, *combo2, *combo3, *combo4, *combo5;
+
+extern GtkAdjustment *adj;
+
+extern gchar *stuff;
+
+
 Treplacerange *values_for_dialog(gchar * dialogitems[], gchar * dialogvalues[], gchar ** custom, Ttagpopup * data);
 void parse_integer_for_dialog(gchar * valuestring, GtkWidget * spin, GtkWidget * entry, GtkWidget * checkbox);
 void init_values_for_dialog(gchar * dialogitems[], gchar * dialogvalues[]);
@@ -78,6 +90,7 @@ void insert_time_cb(GtkWidget * widget, gpointer data);
 void create_buttons(GtkSignalFunc ok_func, gpointer ok_data);
 void create_buttons(GtkSignalFunc ok_func, gpointer ok_data);
 void create_dialog(int width, int height, gchar * title);
+void destroy_dialog(void);
 /* color select button function */
 GtkWidget *color_but_new(GtkWidget * which_entry, GtkWidget * win);
 /* file select button function */
