@@ -18,19 +18,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
-#include <gtk/gtk.h>
+#include "default_include.h"
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
-#include "debug.h"
-#include "config.h"
 #include "gtk_easy.h"
 #include "bluefish.h"
 #include "stringlist.h"
-#include "interface.h"
+#include "document.h"
 #include "html.h"
 #include "cap.h"
 
@@ -220,7 +215,7 @@ void insert_class(GtkWidget * widget, gpointer data)
 	ds = startdialog(_("Insert class"), 3, 4);
 
 	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new(_("Insert class")), 1, 3, 0, 1);
-	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new("CLASS="), 0, 1, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new(_("CLASS=")), 0, 1, 1, 2);
 
 	ds->combo[1] = combo_with_popdown(NULL, main_v->current_project.classlist, 1);
 	gtk_table_attach_defaults(GTK_TABLE(ds->table), ds->combo[1], 1, 4, 1, 2);
@@ -246,8 +241,8 @@ void insert_div(GtkWidget * widget, gpointer data)
 	Thtml2dialog *ds;
 
 	ds = startdialog(_("DIV"), 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new("DIV"), 1, 3, 0, 1);
-	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new("class "), 0, 1, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new(_("DIV")), 1, 3, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new(_("class ")), 0, 1, 1, 2);
 	ds->combo[1] = gtk_combo_new();
 	if (main_v->current_project.classlist != NULL) {
 		gtk_combo_set_popdown_strings(GTK_COMBO(ds->combo[1]), main_v->current_project.classlist);
@@ -275,8 +270,8 @@ void insert_span(GtkWidget * widget, gpointer data)
 	Thtml2dialog *ds;
 
 	ds = startdialog(_("SPAN"), 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new("SPAN"), 1, 3, 0, 1);
-	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new("class "), 0, 1, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new(_("SPAN")), 1, 3, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new(_("class ")), 0, 1, 1, 2);
 	ds->combo[1] = gtk_combo_new();
 	if (main_v->current_project.classlist != NULL) {
 		gtk_combo_set_popdown_strings(GTK_COMBO(ds->combo[1]), main_v->current_project.classlist);
@@ -391,43 +386,83 @@ void insert_in_stylesheet(GtkWidget * widget, gpointer data)
 	gtk_table_attach_defaults(GTK_TABLE(ds->table), gtk_label_new(_("pseudo class")), 0, 1, 3, 4);
 
 	tmplist = g_list_append(NULL, "");
-	tmplist = g_list_append(tmplist, "A");
-	tmplist = g_list_append(tmplist, "B");
-	tmplist = g_list_append(tmplist, "BLOCKQUOTE");
-	tmplist = g_list_append(tmplist, "BODY");
-	tmplist = g_list_append(tmplist, "BR");
-	tmplist = g_list_append(tmplist, "BUTTON");
-	tmplist = g_list_append(tmplist, "CAPTION");
-	tmplist = g_list_append(tmplist, "DD");
-	tmplist = g_list_append(tmplist, "DL");
-	tmplist = g_list_append(tmplist, "DT");
-	tmplist = g_list_append(tmplist, "EM");
-	tmplist = g_list_append(tmplist, "FORM");
-	tmplist = g_list_append(tmplist, "H1");
-	tmplist = g_list_append(tmplist, "H2");
-	tmplist = g_list_append(tmplist, "H3");
-	tmplist = g_list_append(tmplist, "H4");
-	tmplist = g_list_append(tmplist, "H5");
-	tmplist = g_list_append(tmplist, "H6");
-	tmplist = g_list_append(tmplist, "HR");
-	tmplist = g_list_append(tmplist, "I");
-	tmplist = g_list_append(tmplist, "INPUT");
-	tmplist = g_list_append(tmplist, "LI");
-	tmplist = g_list_append(tmplist, "OL");
-	tmplist = g_list_append(tmplist, "P");
-	tmplist = g_list_append(tmplist, "PRE");
-	tmplist = g_list_append(tmplist, "S");
-	tmplist = g_list_append(tmplist, "SELECT");
-	tmplist = g_list_append(tmplist, "STRIKE");
-	tmplist = g_list_append(tmplist, "STRONG");
-	tmplist = g_list_append(tmplist, "SUB");
-	tmplist = g_list_append(tmplist, "SUP");
-	tmplist = g_list_append(tmplist, "TABLE");
-	tmplist = g_list_append(tmplist, "TD");
-	tmplist = g_list_append(tmplist, "TH");
-	tmplist = g_list_append(tmplist, "TR");
-	tmplist = g_list_append(tmplist, "TT");
-	tmplist = g_list_append(tmplist, "UL");
+	tmplist = g_list_append(tmplist, "a");
+	tmplist = g_list_append(tmplist, "abbr");
+	tmplist = g_list_append(tmplist, "acronym");
+	tmplist = g_list_append(tmplist, "address");
+	tmplist = g_list_append(tmplist, "applet");
+	tmplist = g_list_append(tmplist, "area");
+	tmplist = g_list_append(tmplist, "b");
+	tmplist = g_list_append(tmplist, "bdo");
+	tmplist = g_list_append(tmplist, "bockquote");
+	tmplist = g_list_append(tmplist, "body");
+	tmplist = g_list_append(tmplist, "br");
+	tmplist = g_list_append(tmplist, "button");
+	tmplist = g_list_append(tmplist, "caption");
+	tmplist = g_list_append(tmplist, "cite");
+	tmplist = g_list_append(tmplist, "code");
+	tmplist = g_list_append(tmplist, "col");
+	tmplist = g_list_append(tmplist, "colgroup");
+	tmplist = g_list_append(tmplist, "dd");
+	tmplist = g_list_append(tmplist, "del");
+	tmplist = g_list_append(tmplist, "dfn");
+	tmplist = g_list_append(tmplist, "div");
+	tmplist = g_list_append(tmplist, "dl");
+	tmplist = g_list_append(tmplist, "dt");
+	tmplist = g_list_append(tmplist, "em");
+	tmplist = g_list_append(tmplist, "embed");
+	tmplist = g_list_append(tmplist, "fieldset");
+	tmplist = g_list_append(tmplist, "form");
+	tmplist = g_list_append(tmplist, "h1");
+	tmplist = g_list_append(tmplist, "h2");
+	tmplist = g_list_append(tmplist, "h3");
+	tmplist = g_list_append(tmplist, "h4");
+	tmplist = g_list_append(tmplist, "h5");
+	tmplist = g_list_append(tmplist, "h6");
+	tmplist = g_list_append(tmplist, "hr");
+	tmplist = g_list_append(tmplist, "i");
+	tmplist = g_list_append(tmplist, "iframe");
+	tmplist = g_list_append(tmplist, "img");
+	tmplist = g_list_append(tmplist, "input");
+	tmplist = g_list_append(tmplist, "ins");
+	tmplist = g_list_append(tmplist, "kbd");
+	tmplist = g_list_append(tmplist, "label");
+	tmplist = g_list_append(tmplist, "legend");
+	tmplist = g_list_append(tmplist, "li");
+	tmplist = g_list_append(tmplist, "map");
+	tmplist = g_list_append(tmplist, "noframes");
+	tmplist = g_list_append(tmplist, "noscript");
+	tmplist = g_list_append(tmplist, "object");
+	tmplist = g_list_append(tmplist, "ol");
+	tmplist = g_list_append(tmplist, "optgroup");
+	tmplist = g_list_append(tmplist, "option");
+	tmplist = g_list_append(tmplist, "p");
+	tmplist = g_list_append(tmplist, "pre");
+	tmplist = g_list_append(tmplist, "q");
+	tmplist = g_list_append(tmplist, "rb");
+	tmplist = g_list_append(tmplist, "rp");
+	tmplist = g_list_append(tmplist, "rt");
+	tmplist = g_list_append(tmplist, "ruby");
+	tmplist = g_list_append(tmplist, "s");
+	tmplist = g_list_append(tmplist, "samp");
+	tmplist = g_list_append(tmplist, "select");
+	tmplist = g_list_append(tmplist, "small");
+	tmplist = g_list_append(tmplist, "span");
+	tmplist = g_list_append(tmplist, "strike");
+	tmplist = g_list_append(tmplist, "strong");
+	tmplist = g_list_append(tmplist, "sub");
+	tmplist = g_list_append(tmplist, "sup");
+	tmplist = g_list_append(tmplist, "table");
+	tmplist = g_list_append(tmplist, "tbody");
+	tmplist = g_list_append(tmplist, "td");
+	tmplist = g_list_append(tmplist, "textarea");
+	tmplist = g_list_append(tmplist, "tfoot");
+	tmplist = g_list_append(tmplist, "th");
+	tmplist = g_list_append(tmplist, "thead");
+	tmplist = g_list_append(tmplist, "tr");
+	tmplist = g_list_append(tmplist, "tt");
+	tmplist = g_list_append(tmplist, "ul");
+	tmplist = g_list_append(tmplist, "var");
 	ds->combo[8] = combo_with_popdown(NULL, tmplist, 1);
 	g_list_free(tmplist);
 	gtk_table_attach_defaults(GTK_TABLE(ds->table), ds->combo[8], 1, 3, 1, 2);
@@ -437,8 +472,13 @@ void insert_in_stylesheet(GtkWidget * widget, gpointer data)
 	tmplist = g_list_append(tmplist, "link");
 	tmplist = g_list_append(tmplist, "visited");
 	tmplist = g_list_append(tmplist, "active");
+	tmplist = g_list_append(tmplist, "hover");
+	tmplist = g_list_append(tmplist, "focus");
+	tmplist = g_list_append(tmplist, "after");
+	tmplist = g_list_append(tmplist, "before");
 	tmplist = g_list_append(tmplist, "first-line");
 	tmplist = g_list_append(tmplist, "first-letter");
+	tmplist = g_list_append(tmplist, "first-child");
 	ds->combo[10] = combo_with_popdown(NULL, tmplist, 1);
 	g_list_free(tmplist);
 	gtk_table_attach_defaults(GTK_TABLE(ds->table), ds->combo[10], 1, 3, 3, 4);
@@ -562,17 +602,17 @@ void insert_in_stylesheet(GtkWidget * widget, gpointer data)
 
 	/* margin&padding tab completed */
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table,
-							 apply_font_style(gtk_label_new("Margin & padding"), main_v->props.cfg_tab_font));
+							 apply_font_style(gtk_label_new(_("Margin & padding")), main_v->props.cfg_tab_font));
 
 	/* border tab started */
 	table = table = gtk_table_new(4, 8, 0);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("width"), 1, 2, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("color"), 2, 3, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("style"), 3, 4, 3, 4);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("top"), 0, 1, 4, 5);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("right"), 0, 1, 5, 6);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("bottom"), 0, 1, 6, 7);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new("left"), 0, 1, 7, 8);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("width")), 1, 2, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("color")), 2, 3, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("style")), 3, 4, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("top")), 0, 1, 4, 5);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("right")), 0, 1, 5, 6);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("bottom")), 0, 1, 6, 7);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("left")), 0, 1, 7, 8);
 	ds->radio[7] = gtk_radio_button_new_with_label(NULL, _("Insert values per property"));
 	gtk_table_attach_defaults(GTK_TABLE(table), ds->radio[7], 0, 4, 0, 1);
 	group = gtk_radio_button_group(GTK_RADIO_BUTTON(ds->radio[7]));
@@ -658,7 +698,7 @@ void insert_in_stylesheet(GtkWidget * widget, gpointer data)
 	gtk_table_attach_defaults(GTK_TABLE(table), ds->combo[36], 1, 2, 3, 4);
 	/* size&placement tab completed */
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table,
-							 apply_font_style(gtk_label_new("Size & placement"), main_v->props.cfg_tab_font));
+							 apply_font_style(gtk_label_new(_("Size & placement")), main_v->props.cfg_tab_font));
 
 	/* color&background tab started */
 	table = table = gtk_table_new(5, 9, 0);
@@ -704,18 +744,18 @@ void insert_in_stylesheet(GtkWidget * widget, gpointer data)
 	ds->combo[17] = combo_with_popdown(NULL, tmplist, 1);
 	gtk_table_attach_defaults(GTK_TABLE(table), ds->combo[17], 3, 5, 8, 9);
 
-	frame = gtk_frame_new("size unit");
+	frame = gtk_frame_new(_("size unit"));
 	gtk_table_attach(GTK_TABLE(table), frame, 0, 2, 6, 9, GTK_FILL | GTK_EXPAND, GTK_FILL | GTK_EXPAND, 5, 5);
 	vbox = gtk_vbox_new(TRUE, 1);
 	group = NULL;
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
-	ds->radio[4] = gtk_radio_button_new_with_label(NULL, "percentage");
+	ds->radio[4] = gtk_radio_button_new_with_label(NULL, _("percentage"));
 	gtk_box_pack_start(GTK_BOX(vbox), ds->radio[4], TRUE, TRUE, 0);
 	group = gtk_radio_button_group(GTK_RADIO_BUTTON(ds->radio[4]));
-	ds->radio[5] = gtk_radio_button_new_with_label(group, "absolute size");
+	ds->radio[5] = gtk_radio_button_new_with_label(group, _("absolute size"));
 	gtk_box_pack_start(GTK_BOX(vbox), ds->radio[5], TRUE, TRUE, 0);
 	group = gtk_radio_button_group(GTK_RADIO_BUTTON(ds->radio[5]));
-	ds->radio[6] = gtk_radio_button_new_with_label(group, "keyword");
+	ds->radio[6] = gtk_radio_button_new_with_label(group, _("keyword"));
 	gtk_box_pack_start(GTK_BOX(vbox), ds->radio[6], TRUE, TRUE, 0);
 	group = gtk_radio_button_group(GTK_RADIO_BUTTON(ds->radio[6]));
 	gtk_signal_connect(GTK_OBJECT(ds->radio[4]), "clicked", sizing_unit_bg_cb, ds);
@@ -725,7 +765,7 @@ void insert_in_stylesheet(GtkWidget * widget, gpointer data)
 
 	/* color&background tab completed */
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), table,
-							 apply_font_style(gtk_label_new("Color & background"), main_v->props.cfg_tab_font));
+							 apply_font_style(gtk_label_new(_("Color & background")), main_v->props.cfg_tab_font));
 
 	/* text tab started */
 	table = table = gtk_table_new(2, 7, 0);
