@@ -18,8 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 
-extern void insert_class (GtkWidget * widget, gpointer data);
-extern void insert_div(GtkWidget * widget, gpointer data);
-extern void insert_span(GtkWidget * widget, gpointer data);
-extern void insert_in_stylesheet(GtkWidget * widget, gpointer data);
+#ifndef __HTML2_H_
+#define __HTML2_H_
+void insert_class(GtkWidget * widget, gpointer data);
+void insert_div(GtkWidget * widget, gpointer data);
+void insert_span(GtkWidget * widget, gpointer data);
+void insert_in_stylesheet(GtkWidget * widget, gpointer data);
+#endif
