@@ -18,25 +18,21 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include "default_include.h"
 
 #include <stdio.h>
-#include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
 #include <gdk/gdk.h>
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
 #include "cap.h"
-#include "config.h"
 #include "bluefish.h"
 #include "init.h"
 #include "gtk_easy.h"
-#include "debug.h"
 #include "html.h"
-#include "interface.h"
+#include "document.h"
 #include "rpopup.h"
 #include "images.h"
 
@@ -105,6 +101,7 @@ static void image_filename_changed(GtkWidget * widget, Timagewin * image_win)
 	if (image_win->im) {
 		gdk_imlib_destroy_image(image_win->im);
 	}
+	
 	image_win->im = gdk_imlib_load_image(gtk_entry_get_text(GTK_ENTRY(image_win->location)));
 	if (!image_win->im) {
 		return;
@@ -141,13 +138,11 @@ static void image_filename_changed(GtkWidget * widget, Timagewin * image_win)
 		DEBUG_MSG("image_filename_changed, pimap re-set\n");
 		gtk_pixmap_set(GTK_PIXMAP(image_win->pixmap), image_win->p, image_win->m);
 	} else {
-		DEBUG_MSG("image_filename_changed, pimap first time set\n");
+		DEBUG_MSG("image_filename_changed, pximap first time set\n");
 		image_win->pixmap = gtk_pixmap_new(image_win->p, image_win->m);
 		gtk_container_add(GTK_CONTAINER(image_win->frame), image_win->pixmap);
 		gtk_widget_show(image_win->pixmap);
 	}
-
-
 	gdk_imlib_free_pixmap(image_win->p);
 	gdk_imlib_free_pixmap(image_win->m);
 
@@ -182,13 +177,14 @@ static void image_dialog(GtkWidget * widget, gpointer data, gboolean thumb)
 	if (thumb == 1) {
 		image_win->pixwin = window_with_title(_("Insert image as thumbnail"), GTK_WIN_POS_CENTER, GTK_WINDOW_TOPLEVEL, 10);
 	} else {
-		image_win->pixwin = window_with_title(_("Insert image") , GTK_WIN_POS_CENTER, GTK_WINDOW_TOPLEVEL, 10);
+		image_win->pixwin = window_with_title(_("Insert image"), GTK_WIN_POS_CENTER, GTK_WINDOW_TOPLEVEL, 10);
 	}
 
 	hbox = gtk_hbox_new(FALSE, 1);
 	gtk_container_add(GTK_CONTAINER(image_win->pixwin), hbox);
 
 	image_win->frame = gtk_frame_new(_("Preview"));
+/*	gtk_widget_set_usize(image_win->frame, 200, 0); */
 	gtk_box_pack_start(GTK_BOX(hbox), image_win->frame, TRUE, TRUE, 5);
 
 	table = gtk_table_new(13, 4, 1);
@@ -196,16 +192,16 @@ static void image_dialog(GtkWidget * widget, gpointer data, gboolean thumb)
 
 	gtk_widget_realize(image_win->pixwin);
 	image_win->location = gtk_entry_new();
-	gtk_table_attach_defaults(GTK_TABLE(table), image_win->location, 0, 3, 1, 2);
-	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("Image location")), 0, 2, 0, 1);
-	gtk_table_attach_defaults(GTK_TABLE(table), file_but_new(image_win->location, image_win->pixwin, 0), 3, 4, 1, 2);
-	gtk_signal_connect(GTK_OBJECT(image_win->location), "activate", image_filename_changed, image_win);
-	DEBUG_MSG("image_dialog, image_win->location=%p\n", image_win->location);
 	if (tagvalues[4]) {
 		gtk_entry_set_text(GTK_ENTRY(image_win->location), tagvalues[4]);
 	} else {
 		DEBUG_MSG("image_dialog, tagvalues[4]=NULL\n");
 	}
+	gtk_table_attach_defaults(GTK_TABLE(table), image_win->location, 0, 3, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(table), gtk_label_new(_("Image location")), 0, 2, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(table), file_but_new(image_win->location, image_win->pixwin, 0), 3, 4, 1, 2);
+	gtk_signal_connect(GTK_OBJECT(image_win->location), "activate", image_filename_changed, image_win);
+	DEBUG_MSG("image_dialog, image_win->location=%p\n", image_win->location);
 
 	adj = gtk_adjustment_new((gfloat) 0, 0.0, 600.0, 1.0, 5.0, 0.0);
 	image_win->width = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1, 0);
@@ -320,11 +316,13 @@ static void insert_image_html(GtkWidget * widget, Timagewin * win)
 			g_strdup_printf("%s%s%s%s%s", cap("<A HREF=\""), gtk_entry_get_text(GTK_ENTRY(win->location)), cap("\"><IMG SRC=\""),
 							tnfilename, "\"");
 		g_free(tnfilename);
+		tempstring = insert_integer_if_spin(win->width, cap("WIDTH"), tempstring, NULL);
+		tempstring = insert_integer_if_spin(win->height, cap("HEIGHT"), tempstring, NULL);
 	} else {
 		tempstring = g_strdup_printf("%s%s%s", cap("<IMG SRC=\""), gtk_entry_get_text(GTK_ENTRY(win->location)), "\"");
+		tempstring = insert_integer_if_spin(win->width, cap("WIDTH"), tempstring, win->width_perc);
+		tempstring = insert_integer_if_spin(win->height, cap("HEIGHT"), tempstring, win->height_perc);
 	}
-	tempstring = insert_integer_if_spin(win->width, cap("WIDTH"), tempstring, win->width_perc);
-	tempstring = insert_integer_if_spin(win->height, cap("HEIGHT"), tempstring, win->height_perc);
 	tempstring = insert_integer_if_spin(win->border, cap("BORDER"), tempstring, NULL);
 	tempstring = insert_integer_if_spin(win->vspace, cap("VSPACE"), tempstring, NULL);
 	tempstring = insert_integer_if_spin(win->hspace, cap("HSPACE"), tempstring, NULL);
@@ -401,6 +399,8 @@ static void image_adjust_changed(GtkAdjustment * adj, Timagewin * image_win)
 	gtk_pixmap_set(GTK_PIXMAP(image_win->pixmap), image_win->p, image_win->m);
 	gdk_imlib_free_pixmap(image_win->p);
 	gdk_imlib_free_pixmap(image_win->m);
+	gtk_signal_emit_by_name(GTK_OBJECT(image_win->height), "activate");
+	gtk_signal_emit_by_name(GTK_OBJECT(image_win->width), "activate");
 }
 
 /************************************************************************/
