@@ -19,26 +19,22 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "default_include.h"
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
-#include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
-#include "config.h"
 #include "bluefish.h"
 #include "init.h"
 #include "stringlist.h"
 #include "highlight.h"
-#include "debug.h"
 #include "filter.h"
 
 #define DIR_MODE (S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH)	/* same as 0755 */
@@ -55,17 +51,7 @@ GList *config_rc;
 GList *positionlist;
 
 /****************************************************************/
-gint chk_dir(gchar * name);
-gint chk_link(gchar * src_name, gchar * dst_name);
-gint chk_file(gchar * name, gchar * content);
-gint check_directories();
-GList *make_config_list_item(GList * config_list, void *pointer_to_var, unsigned char type_of_var, gchar * name_of_var);
-gint save_config_file(GList * config_list, gchar * filename);
-gint parse_config_file(GList * config_list, gchar * filename);
-void make_syntax_struct_list(void);
-gboolean rcfile_init();
-void parse_config_files(void);
-void save_config_files(void);
+
 /****************************************************************/
 
 
@@ -79,7 +65,7 @@ void save_config_files(void);
  * Small description:
  *      check directory and if not exist create it
  */
-gint chk_dir(gchar * name)
+static gint chk_dir(gchar * name)
 {
 	struct stat filestat;
 
@@ -104,7 +90,7 @@ gint chk_dir(gchar * name)
  * Description:
  *      create symbolic link from dst_name to src_name
  */
-gint chk_link(gchar * src_name, gchar * dst_name)
+static gint chk_link(gchar * src_name, gchar * dst_name)
 {
 	struct stat filestat;
 
@@ -134,7 +120,7 @@ gint chk_link(gchar * src_name, gchar * dst_name)
  * Description:
  *      if file 'name' don`t exists, then create it and write to 'content'
  */
-gint chk_file(gchar * name, gchar * content)
+static gint chk_file(gchar * name, gchar * content)
 {
 	struct stat filestat;
 	FILE *file;
@@ -169,7 +155,7 @@ gint chk_file(gchar * name, gchar * content)
  * Description:
  *      Create necessary directories/links/files
  */
-gint check_directories()
+gint check_files_links_directories()
 {
 	gchar *name, *name2, *homedir;
 
@@ -185,16 +171,14 @@ gint check_directories()
 	chk_dir(strncat(strncpy(name, homedir, PATH_MAX), "/.bluefish/projects/", PATH_MAX));
 	chk_dir(strncat(strncpy(name, homedir, PATH_MAX), "/.bluefish/menu", PATH_MAX));
 	chk_link(strncat(strncpy(name, homedir, PATH_MAX), "/.bluefish/php3_functions", PATH_MAX),
-			 strncat(strncpy(name2, BF_LIB_DIR, PATH_MAX), "php3_functions", PATH_MAX));
+			 strncat(strncpy(name2, PKGDATADIR, PATH_MAX), "php3_functions", PATH_MAX));
 	chk_link(strncat(strncpy(name, homedir, PATH_MAX), "/.bluefish/ssi_functions", PATH_MAX),
-			 strncat(strncpy(name2, BF_LIB_DIR, PATH_MAX), "ssi_functions", PATH_MAX));
+			 strncat(strncpy(name2, PKGDATADIR, PATH_MAX), "ssi_functions", PATH_MAX));
 	chk_link(strncat(strncpy(name, homedir, PATH_MAX), "/.bluefish/rxml_functions", PATH_MAX),
-			 strncat(strncpy(name2, BF_LIB_DIR, PATH_MAX), "rxml_functions", PATH_MAX));
-	chk_file(strncat(strncpy(name, homedir, PATH_MAX), "/.bluefish/rcfile", PATH_MAX),
-			 "browser: netscape -remote OpenUrl\\(%s\\)\nfont: fixed\nweblint: weblint\n\nnotebook_tab_position: top\n");
+			 strncat(strncpy(name2, PKGDATADIR, PATH_MAX), "rxml_functions", PATH_MAX));
+	chk_file(strncat(strncpy(name, homedir, PATH_MAX), "/.bluefish/rcfile", PATH_MAX),RCFILE_DEFAULTS);
 	g_free(name);
 	g_free(name2);
-/*   g_free (homedir); */
 	return 1;
 }
 
@@ -213,6 +197,26 @@ GList *make_config_list_item(GList * config_list, void *pointer_to_var, unsigned
 	return (GList *) g_list_append(config_list, config_list_item);
 }
 
+static void init_prop_integer(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gint default_value)
+{
+	*config_list = make_config_list_item(*config_list, pointer_to_var, 'i', name_of_var);
+	*(gint *) pointer_to_var = default_value;
+}
+
+static void init_prop_string(GList ** config_list, void *pointer_to_var, gchar * name_of_var, gchar * default_value)
+{
+	*config_list = make_config_list_item(*config_list, pointer_to_var, 's', name_of_var);
+	*(gchar **) pointer_to_var = g_strdup(default_value);
+	DEBUG_MSG("init_prop_string, name_of_var=%s, default_value=%s\n", name_of_var, default_value);
+}
+
+static void init_prop_list(GList ** config_list, void *pointer_to_var, gchar * name_of_var)
+{
+	*config_list = make_config_list_item(*config_list, pointer_to_var, 'l', name_of_var);
+	pointer_to_var = NULL;
+}
+
+
 
 gint save_config_file(GList * config_list, gchar * filename)
 {
@@ -299,26 +303,28 @@ gint parse_config_file(GList * config_list, gchar * filename)
 	tmplist = g_list_first(config_list);
 	while (tmplist != NULL) {
 		tmpitem = (Tconfig_list_item *) tmplist->data;
+		DEBUG_MSG("parse_config_file, type=%c, identifier=%s\n", tmpitem->type, tmpitem->identifier);
 		if (tmpitem->type == 'l') {
 			free_stringlist((GList *) * (void **) tmpitem->pointer);
 			(GList *) * (void **) tmpitem->pointer = NULL;
 		}
+		DEBUG_MSG("parse_config_file, type=%c, identifier=%s\n", tmpitem->type, tmpitem->identifier);
 		tmplist = g_list_next(tmplist);
 	}
 	DEBUG_MSG("parse_config_file, all the type 'l' have been emptied\n");
 	DEBUG_MSG("parse_config_file, length rclist=%d\n", g_list_length(rclist));
 /* And now for parsing every line in the config file, first check if there is a valid identifier at the start. */
 	tmplist = g_list_first(rclist);
-	while(tmplist) {
-		tmpstring = (gchar *)tmplist->data;
+	while (tmplist) {
+		tmpstring = (gchar *) tmplist->data;
 
 		if (tmpstring != NULL) {
 			DEBUG_MSG("parse_config_file, tmpstring=%s\n", tmpstring);
 			g_strchug(tmpstring);
 
 			tmplist2 = g_list_first(config_list);
-			while(tmplist2) {
-				tmpitem = (Tconfig_list_item *)tmplist2->data;
+			while (tmplist2) {
+				tmpitem = (Tconfig_list_item *) tmplist2->data;
 				if (g_strncasecmp(tmpitem->identifier, tmpstring, strlen(tmpitem->identifier)) == 0) {
 					/* we have found the correct identifier */
 					DEBUG_MSG("parse_config_file, identifier=%s, string=%s\n", tmpitem->identifier, tmpstring);
@@ -347,15 +353,15 @@ gint parse_config_file(GList * config_list, gchar * filename)
 					}
 					tmplist2 = g_list_last(tmplist2);
 				}
-			tmplist2 = g_list_next(tmplist2);
+				tmplist2 = g_list_next(tmplist2);
 			}
 		}
-	tmplist = g_list_next(tmplist);
+		tmplist = g_list_next(tmplist);
 	}
 	free_stringlist(rclist);
 	return 1;
 }
-#ifdef DEVELOPMENT
+
 static void external_filter_lcb(GtkWidget * widget, gpointer data)
 {
 
@@ -395,7 +401,7 @@ static void external_filter_lcb(GtkWidget * widget, gpointer data)
 	}
 	g_free(in.buf);
 }
-#endif
+
 
 static void external_command_lcb(GtkWidget * widget, gpointer data)
 {
@@ -425,14 +431,12 @@ void make_external_menu_entries(gint which_external)
 
 	DEBUG_MSG("make_external_menu_entries, started with %d\n", which_external);
 	switch (which_external) {
-#ifdef DEVELOPMENT
 	case 1:
 		config_stringlist = main_v->props.external_filters;
 		commandlist = &main_v->filter_strings;
 		callback = external_filter_lcb;
 		menupath = N_("/External/Filters/");
 		break;
-#endif
 	case 2:
 		config_stringlist = main_v->props.external_commands;
 		commandlist = &main_v->command_strings;
@@ -478,37 +482,58 @@ void make_external_menu_entries(gint which_external)
 	DEBUG_MSG("make_external_menu_entries, finished\n");
 }
 
+
 /*
- * Function:  rcfile_init
- * Arguments:   none
- * Return value:
- *      TRUE
+ * Function: main_v_props_init
  * Description:
- *      Initialise variables that are read from the rcfile
+ *      Setting the config variables in main_v->props (Tproperty)
  */
-gboolean rcfile_init()
+static GList *main_v_props_init(GList * config_rc)
 {
-	DEBUG_MSG("rcfile_init started\n");
-	memset(&main_v->props, 0, sizeof(propertystruct));
-	main_v->props.cfg_browser_cline = g_strdup("netscape -remote OpenUrl\\(%s\\)");
-	main_v->props.cfg_editor_font = g_strdup("fixed,*");
-	main_v->props.cfg_tab_font = g_strdup("fixed,*");
-	main_v->props.cfg_tab_pos = g_strdup("top");
-	main_v->props.cfg_weblint_cline = g_strdup("weblint");
-	main_v->props.cfg_thumbnailstring = g_strdup("_thumbnail");
-	main_v->props.cfg_thumbnailtype = g_strdup("jpg");
-	main_v->props.cfg_editor_tabwidth = 8;
-	main_v->props.v_html_tb = 1;
-	main_v->props.v_main_tb = 1;
-	main_v->props.v_custom_tb = 0;
-	main_v->props.lowercase_tags = 0;
-	main_v->props.main_window_h = 400;
-	main_v->props.main_window_w = 600;
-	main_v->props.full_p = 0;
-	main_v->props.full_li = 0;
-	main_v->props.cont_highlight_update = 0;
-	return TRUE;
-};
+	init_prop_string(&config_rc, &main_v->props.cfg_browser_cline, "browser_command:", NETSCAPE_COMMAND);
+	init_prop_string(&config_rc, &main_v->props.cfg_editor_font, "editor_font:", "fixed,*");
+	init_prop_integer(&config_rc, &main_v->props.cfg_editor_tabwidth, "editor_tab_width:", 8);
+	init_prop_string(&config_rc, &main_v->props.cfg_tab_font, "notebook_tab_font:", "fixed,*");
+	init_prop_string(&config_rc, &main_v->props.cfg_tab_pos, "notebook_tab_position:", "bottom");
+	init_prop_string(&config_rc, &main_v->props.cfg_weblint_cline, "weblint_command:", WEBLINT_COMMAND);
+	init_prop_integer(&config_rc, &main_v->props.v_html_tb, "view_html_toolbar:", 1);
+	init_prop_integer(&config_rc, &main_v->props.v_custom_tb, "view_custom_toolbar:", 0);
+	init_prop_integer(&config_rc, &main_v->props.v_main_tb, "view_main_toolbar:", 1);
+	init_prop_integer(&config_rc, &main_v->props.main_window_h, "main_window_height:", 400);
+	init_prop_integer(&config_rc, &main_v->props.main_window_w, "main_window_width:", 600);
+	init_prop_string(&config_rc, &main_v->props.cfg_thumbnailstring, "thumbnail_string:", "_thumbnail");
+	init_prop_string(&config_rc, &main_v->props.cfg_thumbnailtype, "thumbnail_type:", "jpg");
+	init_prop_integer(&config_rc, &main_v->props.full_p, "closing_paragraph_tag:", 1);
+	init_prop_integer(&config_rc, &main_v->props.full_li, "closing_list_item_tag:", 0);
+	init_prop_integer(&config_rc, &main_v->props.lowercase_tags, "lowercase_tags:", 0);
+	init_prop_integer(&config_rc, &main_v->props.word_wrap, "word_wrap:", 0);
+	init_prop_integer(&config_rc, &main_v->props.line_wrap, "line_wrap:", 1);
+	init_prop_integer(&config_rc, &main_v->props.fontset, "fontset:", 0);
+	init_prop_integer(&config_rc, &main_v->props.link_management, "link_management:", 0);
+	init_prop_integer(&config_rc, &main_v->props.defaulthighlight, "defaulthighlight:", 1);
+	init_prop_integer(&config_rc, &main_v->props.cont_highlight_full, "cont_highlight_full:", 0);
+	init_prop_integer(&config_rc, &main_v->props.cont_highlight_update, "continuous_highlight_update:", 0);
+	init_prop_string(&config_rc, &main_v->props.default_charset, "default_charset:", "iso8859-1");
+	init_prop_list(&config_rc, &main_v->props.external_filters, "external_filters:");
+	init_prop_list(&config_rc, &main_v->props.external_commands, "external_commands:");
+	init_prop_list(&config_rc, &main_v->props.syntax_configstrings, "highlight_patterns:");
+	
+	
+
+	/* spell checker options: */
+	
+#ifdef WITH_SPC
+	init_prop_string (&config_rc, &main_v->props.cfg_spc_cline,"spell_checker_command:",ISPELL_COMMAND);
+	init_prop_string (&config_rc, &main_v->props.cfg_spc_lang ,"spell_checker_language:","default");
+        init_prop_integer (&config_rc, &main_v->props.spc_accept_compound,"spell_checker_accept_compound:",0);
+	init_prop_integer (&config_rc, &main_v->props.spc_use_esc_chars,"spell_checker_use_esc_chars:",0);
+        init_prop_string  (&config_rc, &main_v->props.spc_esc_chars,"spell_checker_esc_chars:",NULL);
+        init_prop_integer (&config_rc, &main_v->props.spc_use_pers_dict,"spell_checker_use,pers_dict:",0);
+        init_prop_string  (&config_rc, &main_v->props.spc_use_pers_dict,"spell_checker_pers_dict:",NULL);
+#endif
+	return config_rc;
+
+}
 
 /*
  * Function: parse_config_file
@@ -519,46 +544,19 @@ gboolean rcfile_init()
  * Description:
  *      Parsing config file, initialize some internal variable
  */
-void parse_config_files(void)
+void parse_bluefish_rcfile(void)
 {
 	gchar *filename;
 
 	DEBUG_MSG("parse_config_files, started\n");
-	DEBUG_MSG("parse_config_files, g_get_home_dir=%s\n", g_get_home_dir());
-/* 
- * read the data into the three lists: fonts, targets, urls and colors 
- * You need to add 1 entry to initialize the list before calling get_stringlist()
- */
 
-	rcfile_init();
+	/* set the props struct completely empty */
+	memset(&main_v->props, 0, sizeof(Tproperties));
 
+	/*Make the config_rc list ready for filling with data and set default values */
+	config_rc = main_v_props_init(NULL);
 
-/*Make the config_rc list ready for filling with data */
-
-	config_rc = NULL;
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_browser_cline, 's', "browser_command:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_editor_font, 's', "editor_font:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_editor_tabwidth, 'i', "editor_tab_width:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_tab_font, 's', "notebook_tab_font:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_tab_pos, 's', "notebook_tab_position:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_weblint_cline, 's', "weblint_command:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.v_html_tb, 'i', "view_html_toolbar:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.v_custom_tb, 'i', "view_custom_toolbar:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.v_main_tb, 'i', "view_main_toolbar:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.main_window_h, 'i', "main_window_height:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.main_window_w, 'i', "main_window_width:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_thumbnailstring, 's', "thumbnail_string:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cfg_thumbnailtype, 's', "thumbnail_type:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.full_p, 'i', "closing_paragraph_tag:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.full_li, 'i', "closing_list_item_tag:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.cont_highlight_update, 'i', "continuous_highlight_update:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.lowercase_tags, 'i', "lowercase_tags:");
-#ifdef DEVELOPMENT
-	config_rc = make_config_list_item(config_rc, &main_v->props.external_filters, 'l', "external_filters:");
-#endif
-	config_rc = make_config_list_item(config_rc, &main_v->props.external_commands, 'l', "external_commands:");
-	config_rc = make_config_list_item(config_rc, &main_v->props.syntax_configstrings, 'l', "highlight_patterns:");
-/*Fill the config_rc list with data */
+	/*Fill the config_rc list with data */
 
 	/* g_get_homedir() is broken on some systems, so we use the old method */
 	filename = g_strconcat(getenv("HOME"), "/.bluefish/rcfile", NULL);
@@ -602,3 +600,59 @@ void save_config_files(void)
 	save_config_file(config_rc, filename);
 	g_free(filename);
 };
+
+
+/* commandline functions */
+
+int root_override = 0;
+gchar *load_projectname = NULL;
+GList *load_filenames = NULL;
+
+int parse_commandline(int argc, char **argv)
+{
+
+	int c;
+	gchar *tmpname;
+
+	opterr = 0;
+	DEBUG_MSG("parse_commandline, started\n");
+	while ((c = getopt(argc, argv, "p:hsv?")) != -1) {
+		switch (c) {
+		case 's':
+			root_override = 1;
+			break;
+		case 'v':
+			g_print(CURRENT_VERSION_NAME);
+			g_print("\n");
+			exit(1);
+			break;
+		case 'p':
+			load_projectname = create_full_path(optarg, NULL);
+			DEBUG_MSG("parse_commandline, load_projectname=%s\n", load_projectname);
+			break;
+		case 'h':
+		case '?':
+			g_print(CURRENT_VERSION_NAME);
+			g_print("\nUsage: %s [options] [filename]\n", argv[0]);
+			g_print(_("\nCurrently accepted options are:\n"));
+			g_print(_("-s           skip root check\n"));
+			g_print(_("-v           current version\n"));
+			g_print(_("-h           this help screen\n"));
+			g_print(_("-p filename  load project on startup\n"));
+			exit(1);
+			break;
+		default:
+			DEBUG_MSG("parse_commandline, abort ?!?\n");
+			abort();
+		}
+	}
+	DEBUG_MSG("parse_commandline, optind=%d, argc=%d\n", optind, argc);
+	while (optind < argc) {
+		tmpname = create_full_path(argv[optind], NULL);
+		DEBUG_MSG("parse_commandline, argv[%d]=%s, tmpname=%s\n", optind, argv[optind], tmpname);
+		load_filenames = g_list_append(load_filenames, tmpname);
+		optind++;
+	}
+	DEBUG_MSG("parse_commandline, finished\n");
+	return 0;
+}
