@@ -33,32 +33,19 @@
 #define IMPORTANT_MESSAGE 6000
 #define CRITICAL_MESSAGE 12000
 
-typedef struct {
-	gint currentp;
-	gshort selection;
-	gint startp;
-	gint endp;
-	gfloat adj;
-} Ttext_positions;
-
-
 /* the handle boxes where the toolbars can be added to 
    they are packed in the right place in interface.c, the 
    menubars are added in toolbars.c */
 extern GtkWidget *cust_handle_box, *handle_box, *html_handle_box;
 
 void statusbar_message(gpointer message, gint time);
+gint statusbar_remove(gpointer message_id);
+gint bf_statusbar_message(gpointer message);
+void notebook_next_document_cb(GtkWidget *widget, gpointer data);
+void notebook_prev_document_cb(GtkWidget *widget, gpointer data);
 void switch_to_document(gpointer data);
 void notebook_changed(void);
-void document_need_highlighting(filestruct * whichdoc);
-void destroy_current_document(void);
-void restore_positions(Ttext_positions positions, GtkWidget * textbox);
-Ttext_positions get_positions(GtkWidget * textbox);
-void document_set_fonts(gchar *textfontstring, gchar *labelfontstring, filestruct *document);
-void notebook_set_tab_pos(gchar *position);
-void replace_text(const gchar * newstring, gint pos, gint len);
-void insert_text(const gchar * before, const gchar * after);
-filestruct *new_document(void);
+void notebook_set_tab_pos(gchar * position);
 void startup(void);
 void show_about_window_cb(GtkWidget * w, gpointer data);
 
