@@ -17,32 +17,33 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include "default_include.h"
 
 #include <locale.h>
-#include <libintl.h>
 
 #include <string.h>
 #include <dirent.h>
 #include <sys/types.h>
-/* #include <sys/param.h> */
+
 #include <stdio.h>
 #include <stdlib.h>
-#include <gtk/gtk.h>
-#include "config.h"
+
 #include "bluefish.h"
 #include "callbacks.h"
 #include "html.h"
 #include "html2.h"
-#include "interface.h"
+#include "document.h"			/* insert_text() */
+#include "interface.h"			/* show_about_window_cb() */
+#include "stringlist.h" 		/* edit_stringlist() */
+#include "init.h" 				/* save_config_files() */
+#include "snr2.h" 				/* the new search and replace */
+#include "wml.h"
 #include "images.h"
 #include "wizards.h"
 #include "ref_dialog.h"
 #include "configure.h"
 #include "undo.h"
-#include "snr.h"
 #include "gtk_easy.h"
-#include "debug.h"
-#include "intl.h"
 #include "highlight.h"
 #include "toolbars.h"
 
@@ -64,28 +65,32 @@ typedef struct {
 } cust_menu_struct;
 
 /***************************************************************************/
-
-void insert_char_cb(GtkWidget * widget, gint data);
-void get_main_menu(GtkWidget * window, GtkWidget ** menubar);
-void toggle_cust_menubar_lcb(GtkWidget * w, gpointer data);
-void hide_cust_menubar_cb(GtkWidget * w, gpointer data);
-void show_cust_menubar_cb(GtkWidget * w, gpointer data);
-void remake_cust_menubar(void);
-void make_cust_menubar(void);
-GList *parse_cust_menu_file(char *filename);
-void save_cust_menu(void);
-void edit_custom_menu(GtkWidget * w, gpointer data);
-void main_entry_new(GtkWidget * w, gpointer * tree);
-void entry_new(GtkWidget * w, gpointer * tree);
-void main_entry_update(GtkWidget * w, gpointer * tree);
-void entry_update(GtkWidget * w, gpointer * tree);
-void main_entry_del(GtkWidget * w, gpointer * tree);
-void entry_del(GtkWidget * w, gpointer * tree);
-void entry_save(GtkWidget * w, gpointer * window);
-void entry_selected(GtkWidget * item, cust_menu_struct * entry);
-void main_entry_selected(GtkWidget * item, cust_main_menu_struct * main_entry);
-static void item_response(cust_menu_struct * entry);
+void save_menu_shortcuts();
+void load_menu_shortcuts();
+static void edit_some_list_lcb(GtkWidget * widget, gpointer data);
 gchar *menu_translate(const gchar * path, gpointer data);
+static void insert_char_cb(GtkWidget * widget, gint data);
+void get_main_menu(GtkWidget * window, GtkWidget ** menubar);
+static void toggle_cust_menubar_lcb(GtkWidget * w, gpointer data);
+static void hide_cust_menubar_cb(GtkWidget * w, gpointer data);
+void show_cust_menubar_cb(GtkWidget * w, gpointer data);
+static void remake_cust_menubar(void);
+static void make_cust_menubar(void);
+static void item_response(cust_menu_struct * entry);
+static GList *parse_cust_menu_file(char *filename);
+static void save_cust_menu(void);
+static void edit_custom_menu(GtkWidget * w, gpointer data);
+static void main_entry_new(GtkWidget * w, gpointer * tree);
+static void entry_new(GtkWidget * w, gpointer * tree);
+static void main_entry_update(GtkWidget * w, gpointer * tree);
+static void entry_update(GtkWidget * w, gpointer * tree);
+static void main_entry_del(GtkWidget * w, gpointer * tree);
+static void entry_del(GtkWidget * w, gpointer * tree);
+static void entry_save(GtkWidget * w, gpointer * window);
+static void entry_selected(GtkWidget * item, cust_menu_struct * entry);
+static void main_entry_selected(GtkWidget * item, cust_main_menu_struct * main_entry);
+
+
 
 /***************************************************************************/
 
@@ -101,6 +106,7 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/File/sep2"), NULL, NULL, 0, "<Separator>"},
 	{N_("/File/_Save"), "<control>S", file_save_cb, 0, NULL},
 	{N_("/File/Save _as"), NULL, file_save_as_cb, 0, NULL},
+	{N_("/File/Move to"), NULL, file_move_to_cb, 0, NULL},
 	{N_("/File/Save all"), NULL, file_save_all_cb, 0, NULL},
 	{N_("/File/sep3"), NULL, NULL, 0, "<Separator>"},
 	{N_("/File/Close"), "<control>W", file_close_cb, 0, NULL},
@@ -116,23 +122,24 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/Edit/Select all"), "<control>a", sel_all_cb, 0, NULL},
 	{N_("/Edit/Go to line"), NULL, go_to_line_win_cb, 0, NULL},
 	{N_("/Edit/sep3"), NULL, NULL, 0, "<Separator>"},
-	{N_("/Edit/Find"), "F6", search_search_cmd_cb, 0, NULL},
-	{N_("/Edit/Replace"), "F7", search_replace_cmd_cb, 0, NULL},
-	{N_("/Edit/Find again"), "<shift>F6", search_again_cmd_cb, 0, NULL},
+	{N_("/Edit/Find"), "F6", search_cb, 0, NULL},
+	{N_("/Edit/New find"), NULL, new_search_cb, 0, NULL},
+	{N_("/Edit/Find again"), "<shift>F6", search_again_cb, 0, NULL},
+	{N_("/Edit/Replace"), "F7", replace_cb, 0, NULL},
+	{N_("/Edit/New replace"), NULL, new_replace_cb, 0, NULL},
+	{N_("/Edit/Replace again"), "<shift>F7", replace_again_cb, 0, NULL},
 	{N_("/Edit/sep3"), NULL, NULL, 0, "<Separator>"},
 	{N_("/Edit/Undo"), "<control>z", undo_cb, 0, NULL},
 	{N_("/Edit/Redo"), "<control>r", redo_cb, 0, NULL},
 	{N_("/Edit/Undo all"), NULL, undo_all_cb, 0, NULL},
 	{N_("/Edit/Redo all"), NULL, redo_all_cb, 0, NULL},
-	{N_("/Edit/sep3"), NULL, NULL, 0, "<Separator>"},
-	{N_("/Edit/Preferences"), NULL, configure_cb, 0, NULL},
 	{N_("/_View"), NULL, NULL, 0, "<Branch>"},
 	{N_("/_View/Tearoff1"), NULL, NULL, 0, "<Tearoff>"},
 	{N_("/View/View in _Netscape"), NULL, view_in_netscape_cb, 0, NULL},
 	{N_("/View/sep1"), NULL, NULL, 0, "<Separator>"},
-	{N_("/View/Main toolbar"), NULL, toggle_main_toolbar_lcb, 0, "<ToggleItem>"},
-	{N_("/View/HTML toolbar"), NULL, toggle_html_toolbar_lcb, 0, "<ToggleItem>"},
-	{N_("/View/Custom toolbar"), NULL, toggle_cust_menubar_lcb, 0, "<ToggleItem>"},
+	{N_("/View/Next document"), "F1", notebook_next_document_cb, 0, NULL},
+	{N_("/View/Previous document"), "F2", notebook_prev_document_cb, 0, NULL},
+	{N_("/View/sep3"), NULL, NULL, 0, "<Separator>"},
 	{N_("/View/Highlight syntax"), NULL, toggle_highlight_syntax_cb, 0, "<ToggleItem>"},
 	{N_("/View/Refresh highlighting"), "F5", refresh_hi_cb, 0, NULL},
 	{N_("/_Project"), NULL, NULL, 0, "<Branch>"},
@@ -152,12 +159,12 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/Tags/Tearoff1"), NULL, NULL, 0, "<Tearoff>"},
 	{N_("/Tags/Headings"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Tags/Headings/Tearoff1"), NULL, NULL, 0, "<Tearoff>"},
-	{N_("/Tags/Headings/H1"), NULL, general_html_cb, 18, NULL},
-	{N_("/Tags/Headings/H2"), NULL, general_html_cb, 19, NULL},
-	{N_("/Tags/Headings/H3"), NULL, general_html_cb, 20, NULL},
-	{N_("/Tags/Headings/H4"), NULL, general_html_cb, 21, NULL},
-	{N_("/Tags/Headings/H5"), NULL, general_html_cb, 22, NULL},
-	{N_("/Tags/Headings/H6"), NULL, general_html_cb, 23, NULL},
+	{N_("/Tags/Headings/H1"), "<alt>F1", general_html_cb, 18, NULL},
+	{N_("/Tags/Headings/H2"), "<alt>F2", general_html_cb, 19, NULL},
+	{N_("/Tags/Headings/H3"), "<alt>F3", general_html_cb, 20, NULL},
+	{N_("/Tags/Headings/H4"), "<alt>F4", general_html_cb, 21, NULL},
+	{N_("/Tags/Headings/H5"), "<alt>F5", general_html_cb, 22, NULL},
+	{N_("/Tags/Headings/H6"), "<alt>F6", general_html_cb, 23, NULL},
 	{N_("/Tags/Special"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Tags/Special/Accent"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Tags/Special/Accent/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
@@ -276,17 +283,17 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/Tags/Special/Currency/Yen sign"), NULL, insert_char_cb, 63, NULL},
 	{N_("/Tags/Special/Math-Science"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Tags/Special/Math-Science/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
-	{N_("/Tags/Special/Math-Science/Logical not sign"), NULL, insert_char_cb,
+	{N_("/Tags/Special/Math-Science/Logical not sign"), "<alt>1", insert_char_cb,
 	 64, NULL},
-	{N_("/Tags/Special/Math-Science/Multiplication sign"), NULL,
+	{N_("/Tags/Special/Math-Science/Multiplication sign"), "<alt>8",
 	 insert_char_cb, 65, NULL},
-	{N_("/Tags/Special/Math-Science/Division sign"), NULL, insert_char_cb,
+	{N_("/Tags/Special/Math-Science/Division sign"), "<alt>slash", insert_char_cb,
 	 66, NULL},
 	{N_("/Tags/Special/Math-Science/Plus-minus sign"), NULL, insert_char_cb,
 	 67, NULL},
-	{N_("/Tags/Special/Math-Science/Less-than sign"), NULL, insert_char_cb,
+	{N_("/Tags/Special/Math-Science/Less-than sign"), "<alt>comma", insert_char_cb,
 	 68, NULL},
-	{N_("/Tags/Special/Math-Science/Greater-than sign"), NULL, insert_char_cb,
+	{N_("/Tags/Special/Math-Science/Greater-than sign"), "<alt>period", insert_char_cb,
 	 69, NULL},
 	{N_("/Tags/Special/Math-Science/Superscript 1"), NULL, insert_char_cb,
 	 70, NULL},
@@ -339,72 +346,74 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/Tags/Special/Other/Pilcrow (paragraph sign)"), NULL, insert_char_cb,
 	 93, NULL},
 	{N_("/Tags/Special/Other/Broken bar"), NULL, insert_char_cb, 94, NULL},
-	{N_("/Tags/Special/Other/Soft hypen"), NULL, insert_char_cb, 95, NULL},
+	{N_("/Tags/Special/Other/Soft hypen"), "<alt>minus", insert_char_cb, 95, NULL},
 	{N_("/Tags/Special/Other/Spacing macron"), NULL, insert_char_cb,
 	 96, NULL},
 	{N_("/Tags/Special/Other/Middle dot"), NULL, insert_char_cb,
 	 97, NULL},
 	{N_("/Tags/Formatting"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Tags/Formatting/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
-	{N_("/Tags/Formatting/Bold"), NULL, general_html_cb, 1, NULL},
-	{N_("/Tags/Formatting/Italic"), NULL, general_html_cb, 2, NULL},
-	{N_("/Tags/Formatting/Underline"), NULL, general_html_cb, 3, NULL},
-	{N_("/Tags/Formatting/Strikeout"), NULL, general_html_cb, 4, NULL},
+	{N_("/Tags/Formatting/Bold"), "<alt>b", general_html_cb, 1, NULL},
+	{N_("/Tags/Formatting/Italic"), "<alt>i", general_html_cb, 2, NULL},
+	{N_("/Tags/Formatting/Underline"), "<alt>u", general_html_cb, 3, NULL},
+	{N_("/Tags/Formatting/Strikeout"), "<alt>s", general_html_cb, 4, NULL},
 	{N_("/Tags/Formatting/Strong"), NULL, general_html_cb, 16, NULL},
 	{N_("/Tags/Formatting/Emphasis"), NULL, general_html_cb, 17, NULL},
 	{N_("/Tags/Formatting/<separator>"), NULL, NULL, 0, "<Separator>"},
-	{N_("/Tags/Formatting/Paragraph"), NULL, general_html_cb, 5, NULL},
-	{N_("/Tags/Formatting/Break"), NULL, general_html_cb, 6, NULL},
+	{N_("/Tags/Formatting/Paragraph"), "<alt>P", general_html_cb, 5, NULL},
+	{N_("/Tags/Formatting/Break"),  "<Control><Alt>r", general_html_cb, 6, NULL},
 	{N_("/Tags/Formatting/Break clear all"), NULL, general_html_cb, 41, NULL},
-	{N_("/Tags/Formatting/Non-Breaking Space"), NULL, general_html_cb, 7, NULL},
+	{N_("/Tags/Formatting/Non-Breaking Space"), "<alt>n", general_html_cb, 7, NULL},
 	{N_("/Tags/Formatting/<separator>"), NULL, NULL, 0, "<Separator>"},
-	{N_("/Tags/Formatting/Font Size +1"), NULL, general_html_cb, 11, NULL},
-	{N_("/Tags/Formatting/Font Size -1"), NULL, general_html_cb, 12, NULL},
+	{N_("/Tags/Formatting/Font Size +1"), "<control>equal", general_html_cb, 11, NULL},
+	{N_("/Tags/Formatting/Font Size -1"), "<control>minus", general_html_cb, 12, NULL},
 	{N_("/Tags/Formatting/<separator>"), NULL, NULL, 0, "<Separator>"},
-	{N_("/Tags/Formatting/Preformatted Text"), NULL, general_html_cb, 13, NULL},
-	{N_("/Tags/Formatting/Subscript"), NULL, general_html_cb, 14, NULL},
-	{N_("/Tags/Formatting/Superscript"), NULL, general_html_cb, 15, NULL},
+	{N_("/Tags/Formatting/Preformatted Text"), "<Control><Alt>p", general_html_cb, 13, NULL},
+	{N_("/Tags/Formatting/Subscript"), "<alt><shift>s", general_html_cb, 14, NULL},
+	{N_("/Tags/Formatting/Superscript"), "<alt><control>s", general_html_cb, 15, NULL},
 	{N_("/Tags/Formatting/<separator>"), NULL, NULL, 0, "<Separator>"},
-	{N_("/Tags/Formatting/Center"), NULL, general_html_cb, 8, NULL},
-	{N_("/Tags/Formatting/Align right"), NULL, general_html_cb, 9, NULL},
+	{N_("/Tags/Formatting/Center"), "<alt>c", general_html_cb, 8, NULL},
+	{N_("/Tags/Formatting/Align right"), "<Alt>r", general_html_cb, 9, NULL},
 	{N_("/Tags/Formatting/<separator>"), NULL, NULL, 0, "<Separator>"},
 	{N_("/Tags/Formatting/Comment"), NULL, general_html_cb, 10, NULL},
 	{N_("/Tags/Table"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Tags/Table/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
 	{N_("/Tags/Table/Table"), NULL, general_html_cb, 24, NULL},
 	{N_("/Tags/Table/Tablerow"), NULL, general_html_cb, 25, NULL},
-	{N_("/Tags/Table/Tablehead_cber"), NULL, general_html_cb, 26, NULL},
+	{N_("/Tags/Table/Tableheader"), NULL, general_html_cb, 26, NULL},
 	{N_("/Tags/Table/Tabledata"), NULL, general_html_cb, 27, NULL},
 	{N_("/Tags/Table/Tablecaption"), NULL, general_html_cb, 28, NULL},
 	{N_("/Tags/List"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Tags/List/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
 	{N_("/Tags/List/Unordered list"), NULL, general_html_cb, 33, NULL},
 	{N_("/Tags/List/Ordered list"), NULL, general_html_cb, 34, NULL},
-	{N_("/Tags/List/List item"), NULL, general_html_cb, 35, NULL},
+	{N_("/Tags/List/List item"), "<alt>l", general_html_cb, 35, NULL},
 	{N_("/Tags/List/Definition list"), NULL, general_html_cb, 36, NULL},
-	{N_("/Tags/List/Definition term"), NULL, general_html_cb, 37, NULL},
+	{N_("/Tags/List/Definition term"), "<alt>d", general_html_cb, 37, NULL},
 	{N_("/Tags/List/Definition"), NULL, general_html_cb, 38, NULL},
 	{N_("/Tags/List/menu"), NULL, general_html_cb, 39, NULL},
+	{N_("/Tags/Replace iso 8859-1 chars"), NULL, iso8859_1_replace_cb, 39, NULL},
+	{N_("/Tags/Replace ascii chars"), NULL, ascii_replace_cb, 39, NULL},
 	{N_("/_Dialogs"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Dialogs/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
 	{N_("/Dialogs/General"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Dialogs/General/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
-	{N_("/Dialogs/General/Quickstart"), NULL, quickstart, 0, NULL},
+	{N_("/Dialogs/General/Quickstart"), "<alt>q", quickstart, 0, NULL},
 	{N_("/Dialogs/General/DTD"), NULL, dtd_cb, 0, NULL},
 	{N_("/Dialogs/General/Head"), NULL, head_cb, 0, NULL},
 	{N_("/Dialogs/General/Body"), NULL, body_cb, 0, NULL},
-	{N_("/Dialogs/General/Anchor"), NULL, quickanchor_cb, 0, NULL},
+	{N_("/Dialogs/General/Anchor"), "<alt>a", quickanchor_cb, 0, NULL},
 	{N_("/Dialogs/General/Email"), NULL, email_cb, 0, NULL},
-	{N_("/Dialogs/General/Rule"), NULL, quickrule_cb, 0, NULL},
-	{N_("/Dialogs/General/Font"), NULL, fontdialog_cb, 0, NULL},
+	{N_("/Dialogs/General/Rule"), "<alt>h", quickrule_cb, 0, NULL},
+	{N_("/Dialogs/General/Font"), "<alt>f", fontdialog_cb, 0, NULL},
 	{N_("/Dialogs/General/Basefont"), NULL, basefont_cb, 0, NULL},
 	{N_("/Dialogs/General/Quicklist"), NULL, quicklist_cb, 0, NULL},
-	{N_("/Dialogs/General/Meta"), NULL, meta_cb, 0, NULL},
+	{N_("/Dialogs/General/Meta"), "<alt>m", meta_cb, 0, NULL},
 	{N_("/Dialogs/General/Embed"), NULL, embed_cb, 0, NULL},
 	{N_("/Dialogs/General/Select colour"), NULL, sel_colour_cb, 0, NULL},
 	{N_("/Dialogs/General/Insert time"), NULL, insert_time_cb, 0, NULL},
-	{N_("/Dialogs/General/Insert image"), NULL, image_insert_dialog_cb, 0, NULL},
-	{N_("/Dialogs/General/Insert thumbnail"), NULL, image_thumbnail_dialog_cb, 0, NULL},
+	{N_("/Dialogs/General/Insert image"), "<control>i", image_insert_dialog_cb, 0, NULL},
+	{N_("/Dialogs/General/Insert thumbnail"), "<control>t", image_thumbnail_dialog_cb, 0, NULL},
 	{N_("/Dialogs/Table"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Dialogs/Table/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
 	{N_("/Dialogs/Table/Table"), NULL, tabledialog_cb, 0, NULL},
@@ -434,17 +443,51 @@ static GtkItemFactoryEntry menu_items[] = {
 	{N_("/Dialogs/Form/Radio buttons"), NULL, radiodialog_cb, 0, NULL},
 	{N_("/Dialogs/Form/Check buttons"), NULL, checkdialog_cb, 0, NULL},
 	{N_("/Dialogs/Form/Select"), NULL, selectdialog_cb, 0, NULL},
+	{N_("/Dialogs/_WML"), NULL, NULL, 0, "<Branch>"},
+	{N_("/Dialogs/WML/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
+	{N_("/Dialogs/WML/Standard Document"), NULL, general_wml_cb, 6, NULL},
+	{N_("/Dialogs/WML/Card"), NULL, carddialog_cb, 0, NULL},
+	{N_("/Dialogs/WML/Postfield"), NULL, postfielddialog_cb, 0, NULL},
+	{N_("/Dialogs/WML/Go"), NULL, godialog_cb, 0, NULL},
+	{N_("/Dialogs/WML/Do"), NULL, dodialog_cb, 0, NULL},
+	{N_("/Dialogs/WML/Anchor"), NULL, anchordialog_cb, 0, NULL},
+	{N_("/Dialogs/WML/Access"), NULL, accessdialog_cb, 0, NULL},
+	{N_("/Dialogs/WML/sep11"), NULL, NULL, 0, "<Separator>"},
+	{N_("/Dialogs/WML/Paragraph"), NULL, general_wml_cb, 1, NULL},
+	{N_("/Dialogs/WML/Line Break"), NULL, general_wml_cb, 2, NULL},
+	{N_("/Dialogs/WML/Italic"), NULL, general_wml_cb, 3, NULL},
+	{N_("/Dialogs/WML/Non-Breaking Space"), NULL, general_wml_cb, 4, NULL},
+	{N_("/Dialogs/WML/Bold"), NULL, general_wml_cb, 5, NULL},
+	{N_("/Dialogs/WML/sep12"), NULL, NULL, 0, "<Separator>"},
+	{N_("/Dialogs/WML/Prev"), NULL, general_wml_cb, 7, NULL},
+	{N_("/Dialogs/WML/Refresh"), NULL, general_wml_cb, 8, NULL},
+	{N_("/Dialogs/WML/Noop"), NULL, general_wml_cb, 9, NULL},
+	{N_("/Dialogs/WML/sep13"), NULL, NULL, 0, "<Separator>"},
+	{N_("/Dialogs/WML/Set Variable"), NULL, vardialog_cb, 0, NULL},
 	{N_("/_External"), NULL, NULL, 0, "<Branch>"},
 	{N_("/External/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
 	{N_("/External/Weblint"), NULL, run_weblint_cb, 0, NULL},
 	{N_("/External/sep1"), NULL, NULL, 0, "<Separator>"},
-#ifdef DEVELOPMENT
 	{N_("/External/Filters"), NULL, NULL, 0, "<Branch>"},
 	{N_("/External/Filters/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
-#endif
 	{N_("/External/Commands"), NULL, NULL, 0, "<Branch>"},
 	{N_("/External/Commands/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
-	{N_("/_Help"), NULL, NULL, 0, "<LastBranch>"},
+	{N_("/_Options"), NULL, NULL, 0, "<Branch>"},
+	{N_("/Options/tearoff1"), NULL, NULL, 0, "<Tearoff>"},
+	{N_("/Options/Preferences"), NULL, configure_cb, 0, NULL},
+	{N_("/Options/View Main toolbar"), NULL, toggle_main_toolbar_lcb, 0, "<ToggleItem>"},
+	{N_("/Options/View HTML toolbar"), NULL, toggle_html_toolbar_lcb, 0, "<ToggleItem>"},
+	{N_("/Options/View Custom toolbar"), NULL, toggle_cust_menubar_lcb, 0, "<ToggleItem>"},
+	{N_("/Options/sep2"), NULL, NULL, 0, "<Separator>"},
+	{N_("/Options/_Lists"), NULL, NULL, 0, "<Branch>"},
+	{N_("/Options/Lists/External filters"), NULL, edit_some_list_lcb, 1, NULL},
+	{N_("/Options/Lists/External programs"), NULL, edit_some_list_lcb, 2, NULL},
+	{N_("/Options/Lists/Syntax highlighting"), NULL, edit_some_list_lcb, 3, NULL},
+	{N_("/Options/Lists/Reset syntax highlighting"), NULL, reset_syntax_highlighting_lcb, 0, NULL},
+	{N_("/Options/sep1"), NULL, NULL, 0, "<Separator>"},
+	{N_("/Options/Save config"), NULL, save_config_files, 0, NULL},
+	{N_("/Options/Save shortcut key settings"), NULL, save_menu_shortcuts, 0, NULL},
+	{N_("/_Help"), NULL, NULL, 0, "<Branch>"},
 	{N_("/Help/_About"), NULL, show_about_window_cb, 0, NULL}
 };
 
@@ -469,7 +512,48 @@ static gchar *sp_chars[] = {
 	"&ordf;", "&ordm;", "&para;", "&brvbar;", "&shy;", "&macr;",
 	"&middot;"
 };
+#ifndef PATH_MAX
+#define PATH_MAX 1024
+#endif
 
+void save_menu_shortcuts() {
+	gchar *filename;
+	
+	filename = g_malloc(PATH_MAX);
+	filename = strncat(strncpy(filename, g_get_home_dir(), PATH_MAX), "/.bluefish/menudump", PATH_MAX);
+	gtk_item_factory_dump_rc(filename, NULL, TRUE);
+	g_free(filename);
+}
+
+void load_menu_shortcuts() {
+	gchar *filename;
+	
+	filename = g_malloc(PATH_MAX);
+	filename = strncat(strncpy(filename, g_get_home_dir(), PATH_MAX), "/.bluefish/menudump", PATH_MAX);
+	gtk_item_factory_parse_rc(filename);
+	g_free(filename);
+}
+
+
+static void edit_some_list_lcb(GtkWidget * widget, gpointer data)
+{
+	switch (GPOINTER_TO_INT(data)) {
+	case 1:
+		main_v->props.external_filters = edit_stringlist(main_v->props.external_filters, _("Bluefish configuration - external filters"), 7);
+		break;
+	case 2:
+		main_v->props.external_commands =
+			edit_stringlist(main_v->props.external_commands, _("Bluefish configuration - external commands"), 7);
+		break;
+	case 3:
+		main_v->props.syntax_configstrings =
+			edit_stringlist(main_v->props.syntax_configstrings, _("Bluefish configuration - syntax highlighting"), 8);
+		break;
+	default:
+
+		break;
+	}
+}
 
 
 /* 
@@ -477,7 +561,6 @@ static gchar *sp_chars[] = {
  * they're !NULL after initialisation 
  */
 
-
 GList *entry_list_list;
 GtkWidget *entry1, *entry2, *entry3, *entry4;
 extern GtkWidget *cust_widget;
@@ -488,7 +571,7 @@ cust_main_menu_struct *last_main_entry = NULL;
 
 /***************************************************************************/
 /* takes care of inserting the special characters */
-void insert_char_cb(GtkWidget * widget, gint data)
+static void insert_char_cb(GtkWidget * widget, gint data)
 {
 	insert_text(sp_chars[data], "");
 }
@@ -511,14 +594,14 @@ void get_main_menu(GtkWidget * window, GtkWidget ** menubar)
 	gtk_window_add_accel_group(GTK_WINDOW(window), accel_group);
 	if (menubar)
 		*menubar = gtk_item_factory_get_widget(item_factory, "<main>");
-	setup_toggle_item(item_factory, "/View/Main toolbar", main_v->props.v_main_tb);
-	setup_toggle_item(item_factory, "/View/HTML toolbar", main_v->props.v_html_tb);
-	setup_toggle_item(item_factory, "/View/Custom toolbar", main_v->props.v_custom_tb);
+	setup_toggle_item(item_factory, "/Options/View Main toolbar", main_v->props.v_main_tb);
+	setup_toggle_item(item_factory, "/Options/View HTML toolbar", main_v->props.v_html_tb);
+	setup_toggle_item(item_factory, "/Options/View Custom toolbar", main_v->props.v_custom_tb);
 	setup_toggle_item(item_factory, "/View/Highlight syntax", main_v->props.cont_highlight_update);
 }
 
 
-void toggle_cust_menubar_lcb(GtkWidget * w, gpointer data)
+static void toggle_cust_menubar_lcb(GtkWidget * w, gpointer data)
 {
 	if (GTK_WIDGET_VISIBLE(cust_handle_box)) {
 		hide_cust_menubar_cb(NULL, NULL);
@@ -527,7 +610,7 @@ void toggle_cust_menubar_lcb(GtkWidget * w, gpointer data)
 	}
 }
 
-void hide_cust_menubar_cb(GtkWidget * w, gpointer data)
+static void hide_cust_menubar_cb(GtkWidget * w, gpointer data)
 {
 	gtk_widget_hide(cust_handle_box);
 }
@@ -540,7 +623,7 @@ void show_cust_menubar_cb(GtkWidget * w, gpointer data)
 	gtk_widget_show(cust_handle_box);
 }
 
-void remake_cust_menubar(void)
+static void remake_cust_menubar(void)
 {
 	int count, count2;
 	cust_main_menu_struct *main_entry;
@@ -576,7 +659,7 @@ void remake_cust_menubar(void)
 	DEBUG_MSG("remake_cust_menubar, finished\n");
 }
 
-void make_cust_menubar(void)
+static void make_cust_menubar(void)
 {
 	GtkWidget *menu, *item;
 	int count;
@@ -662,7 +745,7 @@ static void item_response(cust_menu_struct * entry)
 	insert_text(entry->bef_html, entry->aft_html);
 }
 
-GList *parse_cust_menu_file(char *filename)
+static GList *parse_cust_menu_file(char *filename)
 {
 
 	GList *return_list;
@@ -709,7 +792,7 @@ GList *parse_cust_menu_file(char *filename)
 	return return_list;
 }
 
-void save_cust_menu(void)
+static void save_cust_menu(void)
 {
 	gchar *filename, *tmpstring;
 	gint count, count2;
@@ -750,7 +833,7 @@ void save_cust_menu(void)
 }
 
 
-void edit_custom_menu(GtkWidget * w, gpointer data)
+static void edit_custom_menu(GtkWidget * w, gpointer data)
 {
 /*
  * the custom menu is build out of a list, the entry_list_list
@@ -915,7 +998,7 @@ void edit_custom_menu(GtkWidget * w, gpointer data)
 	gtk_widget_show(hbox2);
 
 	but_save = bf_stock_ok_button(GTK_SIGNAL_FUNC(entry_save), (gpointer) menu_window);
-	but_cancel = bf_stock_cancel_button(GTK_SIGNAL_FUNC(window_close), (gpointer) menu_window);
+	but_cancel = bf_stock_cancel_button(GTK_SIGNAL_FUNC(window_close_by_data_cb), (gpointer) menu_window);
 	gtk_box_pack_start(GTK_BOX(hbox2), but_save, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox2), but_cancel, TRUE, TRUE, 0);
 	gtk_widget_show(but_save);
@@ -924,7 +1007,7 @@ void edit_custom_menu(GtkWidget * w, gpointer data)
 	gtk_widget_show(menu_window);
 }
 
-void main_entry_new(GtkWidget * w, gpointer * tree)
+static void main_entry_new(GtkWidget * w, gpointer * tree)
 {
 	gchar *tmpstring;
 	cust_main_menu_struct *main_entry;
@@ -950,7 +1033,7 @@ void main_entry_new(GtkWidget * w, gpointer * tree)
 	DEBUG_MSG("main_entry_new, entry_list_list length=%d\n", g_list_length(entry_list_list));
 }
 
-void entry_new(GtkWidget * w, gpointer * tree)
+static void entry_new(GtkWidget * w, gpointer * tree)
 {
 	gchar *tmpstring;
 	cust_main_menu_struct *main_entry = NULL;
@@ -1026,7 +1109,7 @@ void entry_new(GtkWidget * w, gpointer * tree)
 	DEBUG_MSG("entry_new, finished, on subtree=%p, tree=%p\n", entry->subtree, tree);
 }
 
-void main_entry_update(GtkWidget * w, gpointer * tree)
+static void main_entry_update(GtkWidget * w, gpointer * tree)
 {
 	gchar *tmpstring;
 
@@ -1046,7 +1129,7 @@ void main_entry_update(GtkWidget * w, gpointer * tree)
 	}
 }
 
-void entry_update(GtkWidget * w, gpointer * tree)
+static void entry_update(GtkWidget * w, gpointer * tree)
 {
 	gchar *tmpstring;
 
@@ -1074,7 +1157,7 @@ void entry_update(GtkWidget * w, gpointer * tree)
 	}
 }
 
-void main_entry_del(GtkWidget * w, gpointer * tree)
+static void main_entry_del(GtkWidget * w, gpointer * tree)
 {
 	GList *i;
 	gint count2;
@@ -1102,7 +1185,7 @@ void main_entry_del(GtkWidget * w, gpointer * tree)
 	}
 }
 
-void entry_del(GtkWidget * w, gpointer * tree)
+static void entry_del(GtkWidget * w, gpointer * tree)
 {
 	GList *i;
 
@@ -1119,7 +1202,7 @@ void entry_del(GtkWidget * w, gpointer * tree)
 	}
 }
 
-void entry_save(GtkWidget * w, gpointer * window)
+static void entry_save(GtkWidget * w, gpointer * window)
 {
 	save_cust_menu();
 	remake_cust_menubar();
@@ -1130,7 +1213,7 @@ void entry_save(GtkWidget * w, gpointer * window)
 	DEBUG_MSG("entry_save, finished\n");
 }
 
-void entry_selected(GtkWidget * item, cust_menu_struct * entry)
+static void entry_selected(GtkWidget * item, cust_menu_struct * entry)
 {
 	gtk_entry_set_text(GTK_ENTRY(entry2), entry->name);
 	gtk_entry_set_text(GTK_ENTRY(entry3), entry->bef_html);
@@ -1139,7 +1222,7 @@ void entry_selected(GtkWidget * item, cust_menu_struct * entry)
 	DEBUG_MSG("entry_selected, entry->name=%s, last_entry=%p\n", entry->name, entry);
 }
 
-void main_entry_selected(GtkWidget * item, cust_main_menu_struct * main_entry)
+static void main_entry_selected(GtkWidget * item, cust_main_menu_struct * main_entry)
 {
 	gtk_entry_set_text(GTK_ENTRY(entry1), main_entry->name);
 	last_main_entry = main_entry;
