@@ -26,12 +26,10 @@
 
 #include "intl.h"
 
-/* add some internal include, where define file_open/file_new/etc */
-
+void save_menu_shortcuts();
+void load_menu_shortcuts();
+void get_main_menu(GtkWidget * window, GtkWidget ** menubar);
 void show_cust_menubar_cb(GtkWidget * w, gpointer data);
-void hide_cust_menubar_cb(GtkWidget * w, gpointer data);
-void setup_toggle_item(GtkItemFactory * ifactory, gchar * path, gint state);
-
 #ifdef ENABLE_NLS
 gchar *menu_translate(const gchar * path, gpointer data);
 #else
