@@ -20,6 +20,7 @@
  * To add:      Catch errors
  *                      Redirection
  */
+#include "default_include.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -32,18 +33,13 @@
 #include <netinet/in.h>
 #include <sys/socket.h>
 #include <arpa/inet.h>
-#include <gtk/gtk.h>
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
-#include "config.h"
 #include "bluefish.h"
 #include "interface.h"
 #include "network.h"
-#include "widgets.h"
-#include "debug.h"
+#include "document.h"
 
 /* again extern ? TRY TO AVOID EXTERN DEFINITIONS IN .C FILES!!!!
 USE #INCLUDE STATEMENTS INSTEAD!!!
