@@ -16,22 +16,18 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include "default_include.h"
 
-#include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
-#include "config.h"
 #include "bluefish.h"
 #include "ref_dialog.h"
-#include "interface.h"
+#include "document.h"
 #include "gtk_easy.h"
-#include "debug.h"
 
 /* This is the struct that holds the info for every group of functions  */
 typedef struct {
