@@ -17,26 +17,22 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include "default_include.h"
 
-#include <gtk/gtk.h>
 #include <string.h>
 #include <ctype.h>
 
-#include "intl.h"
-#include "config.h"
-
 #include "bluefish.h"
 #include "html.h"
+#include "wml.h"
 #include "images.h"
-#include "debug.h"
-#include "snr.h"
+#include "document.h"
 #include "undo.h"
 #include "highlight.h"
 
 /**************************************************************************/
 
 gint in_tag(gchar * text, gint pos);
-gint rpopup_eventh(GtkWidget * widget, GdkEvent * event);
 static gint xy_to_cursor_pos(gdouble x, gdouble y);
 static void edit_tag_cb(gint pos);
 static void parse_tagstring(gchar * tagstring, gint pos, gint len);
@@ -315,6 +311,27 @@ static void parse_tagstring(gchar * tagstring, gint pos, gint len)
 	if (strcmp(tmpstring, "meta") == 0) {
 		meta_cb(NULL, tag_popup);
 	}
+	if (strcmp(tmpstring, "card") == 0) {
+		carddialog_cb(NULL, tag_popup);
+	}
+	if (strcmp(tmpstring, "postfield") == 0) {
+		postfielddialog_cb(NULL, tag_popup);
+	}
+	if (strcmp(tmpstring, "setvar") == 0) {
+		vardialog_cb(NULL, tag_popup);
+	}
+	if (strcmp(tmpstring, "go") == 0) {
+		godialog_cb(NULL, tag_popup);
+	}
+	if (strcmp(tmpstring, "do") == 0) {
+		dodialog_cb(NULL, tag_popup);
+	}
+	if (strcmp(tmpstring, "anchor") == 0) {
+		anchordialog_cb(NULL, tag_popup);
+	}
+	if (strcmp(tmpstring, "access") == 0) {
+		accessdialog_cb(NULL, tag_popup);
+	}
 	if (strcmp(tmpstring, "input") == 0) {
 		DEBUG_MSG("parse_tagstring, identified as INPUT tag, splitting tag!\n");
 		input_tag_splitter(NULL, tag_popup);
@@ -369,25 +386,12 @@ static GtkWidget *rpopup_create_menu(GdkEventButton * pevent)
 /*************************************************************************/
 
 
-
-gint rpopup_eventh(GtkWidget * widget, GdkEvent * event)
+void rpopup_eventh(GdkEventButton* bevent)
 {
 	GtkWidget *menu;
 
-	if (event->type == GDK_BUTTON_PRESS) {
-		GdkEventButton *bevent = (GdkEventButton *) event;
-		if (bevent->button == 3) {
-			DEBUG_MSG("rpopup_eventh, bevent->button=%d\n", bevent->button);
-			menu = rpopup_create_menu(bevent);
-			gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, bevent->button, bevent->time);
-			/* Tell calling code that we have handled this event; the buck
-			 * stops here. */
-			return TRUE;
-		}
-	}
-
-	/* Tell calling code that we have not handled this event; pass it on. */
-	return FALSE;
+	menu = rpopup_create_menu(bevent);
+	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, bevent->button, bevent->time);
 }
 
 
