@@ -17,21 +17,16 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include "default_include.h"
 
-#include <gtk/gtk.h>
 
 #include <stdio.h>
-
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
-
 
 #include "bluefish.h"
 #include "html.h"
 #include "stringlist.h"
 #include "gtk_easy.h"
-#include "debug.h"
 
 #define STRING_MAX_SIZE 1024
 
@@ -79,7 +74,9 @@ GList *edit_stringlist(GList * which_list, gchar * title, gint what_list)
 	   GTK_SIGNAL_FUNC(edit_stringlist_cancel), edits); */
 	vbox = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(edits->window), vbox);
-
+	gtk_widget_realize(edits->window);
+	/* is needed here on top because file button needs it */
+	edits->ins_upd_entry = gtk_entry_new_with_max_length(900);
 	switch (what_list) {
 	case 1:
 		/* files */
@@ -135,7 +132,6 @@ GList *edit_stringlist(GList * which_list, gchar * title, gint what_list)
 	}
 	gtk_clist_thaw(GTK_CLIST(edits->clist));
 	DEBUG_MSG("edit_stringlist, entry to go\n");
-	edits->ins_upd_entry = gtk_entry_new_with_max_length(900);
 	gtk_table_attach_defaults(GTK_TABLE(table), edits->ins_upd_entry, 0, 4, 0, 1);
 	gtk_widget_realize(GTK_WIDGET(edits->window));
 	if (but_var != NULL) {
