@@ -17,9 +17,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include "default_include.h"
 
 #include <locale.h>
-#include <libintl.h>
 
 #include <string.h>
 #include <dirent.h>
@@ -27,25 +27,27 @@
 /* #include <sys/param.h> */
 #include <stdio.h>
 #include <stdlib.h>
-#include <gtk/gtk.h>
-#include "config.h"
+
+
 #include "bluefish.h"
 #include "pixmaps.h"
 #include "toolbars.h"
 #include "callbacks.h"
 #include "html.h"
 #include "html2.h"
+#include "wml.h"
 #include "interface.h"
 #include "images.h"
 #include "wizards.h"
 #include "ref_dialog.h"
 #include "configure.h"
 #include "undo.h"
-#include "snr.h"
+#include "snr2.h"
 #include "gtk_easy.h"
-#include "debug.h"
-#include "intl.h"
 
+/* define WITH_SPC */
+#include "config.h"
+#include "spell_gui.h"
 
 typedef struct {
 	gchar *name;
@@ -163,11 +165,11 @@ void make_main_toolbar(void)
 	gtk_toolbar_append_item(GTK_TOOLBAR(main_widget), NULL, _("Paste"), "",
 							new_pixmap(007, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(paste_cb), NULL);
 	gtk_toolbar_append_item(GTK_TOOLBAR(main_widget), NULL, _("Search"), "",
-							new_pixmap(010, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(search_search_cmd_cb), NULL);
+							new_pixmap(010, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(search_cb), NULL);
 	gtk_toolbar_append_item(GTK_TOOLBAR(main_widget), NULL,
 							_("Search and Replace"), "", new_pixmap(011,
 																	main_v->main_window->window,
-																	NULL), GTK_SIGNAL_FUNC(search_replace_cmd_cb), NULL);
+																	NULL), GTK_SIGNAL_FUNC(replace_cb), NULL);
 	gtk_toolbar_append_space(GTK_TOOLBAR(main_widget));
 	gtk_toolbar_append_item(GTK_TOOLBAR(main_widget), NULL, _("Undo"), "",
 							new_pixmap(012, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(undo_cb), NULL);
@@ -177,8 +179,10 @@ void make_main_toolbar(void)
 	gtk_toolbar_append_item(GTK_TOOLBAR(main_widget), NULL, _("Configure"),
 							"", new_pixmap(014, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(configure_cb), NULL);
 	gtk_toolbar_append_item(GTK_TOOLBAR(main_widget), NULL, _("Print"), "", new_pixmap(015, main_v->main_window->window, NULL), NULL, NULL);
+#ifdef WITH_SPC	
 	gtk_toolbar_append_item(GTK_TOOLBAR(main_widget), NULL, _("Spellcheck"),
-							"", new_pixmap(016, main_v->main_window->window, NULL), NULL, NULL);
+							"", new_pixmap(016, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(spell_check_cb), NULL);
+#endif	
 	gtk_widget_show(main_widget);
 	DEBUG_MSG("make_main_widget, end\n");
 }
@@ -444,6 +448,47 @@ void make_html_toolbar(void)
 
 	flush_toolbar(_(" CSS "), html_toolbar, html_widget);
 
+	/* WML toolbar */
+	html_toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_BOTH);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Standard WML Document"),
+							"", new_pixmap(400, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 6);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Card Element"),
+							"", new_pixmap(402, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(carddialog_cb), NULL);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Postfield Element"),
+							"", new_pixmap(408, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(postfielddialog_cb), NULL);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Go Element"),
+							"", new_pixmap(410, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(godialog_cb), NULL);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Do Element"),
+							"", new_pixmap(414, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(dodialog_cb), NULL);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Anchor Element"),
+							"", new_pixmap(415, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(anchordialog_cb), NULL);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Access Element"),
+							"", new_pixmap(416, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(accessdialog_cb), NULL);
+	gtk_toolbar_append_space(GTK_TOOLBAR(html_toolbar));
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Bold"),
+							"", new_pixmap(401, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 5);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Italic"),
+							"", new_pixmap(404, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 3);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Insert a Paragraph"),
+							"", new_pixmap(406, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 1);
+	gtk_toolbar_append_space(GTK_TOOLBAR(html_toolbar));
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Line Break"),
+							"", new_pixmap(403, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 2);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Non-breaking Space"),
+							"", new_pixmap(405, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 4);
+	gtk_toolbar_append_space(GTK_TOOLBAR(html_toolbar));
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Previous Document in History"),
+							"", new_pixmap(411, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 7);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Refresh Document"),
+							"", new_pixmap(412, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 8);
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("No Operation"),
+							"", new_pixmap(413, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(general_wml_cb), (gpointer *) 9);
+	gtk_toolbar_append_space(GTK_TOOLBAR(html_toolbar));
+	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Setvar"),
+							"", new_pixmap(409, main_v->main_window->window, NULL), GTK_SIGNAL_FUNC(vardialog_cb), NULL);
+
+	flush_toolbar(_(" WML "), html_toolbar, html_widget);
+
 	/* other toolbar */
 	html_toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_BOTH);
 	gtk_toolbar_append_item(GTK_TOOLBAR(html_toolbar), NULL, _("Imagemap"),
@@ -497,349 +542,3 @@ void flush_toolbar(gchar * labeltext, GtkWidget * toolbar, GtkWidget * notebook)
 }
 
 
-
-
-/* ------------------------------------------
- * These functions are only declared in the top of toolbars.c
- * they are only accessible from within this file
- * --------------------------------------------- */
-
-GtkWidget *new_pixmap(int type, GdkWindow * window, GdkColor * background)
-{
-	GtkWidget *wpixmap;
-	GdkPixmap *pixm = NULL;
-	GdkBitmap *mask = NULL;
-	/* editor toolbar stuff */
-	switch (type) {
-	case 000:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, new_xpm);
-		break;
-	case 001:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, open_xpm);
-		break;
-	case 002:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, save_xpm);
-		break;
-	case 003:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, save_as_xpm);
-		break;
-	case 004:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, close_xpm);
-		break;
-	case 005:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, copy_xpm);
-		break;
-	case 006:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, cut_xpm);
-		break;
-	case 007:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, paste_xpm);
-		break;
-	case 010:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, search_xpm);
-		break;
-	case 011:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, search_replace_xpm);
-		break;
-	case 012:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, undo_xpm);
-		break;
-	case 013:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, redo_xpm);
-		break;
-	case 014:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, preferences_xpm);
-		break;
-	case 015:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, print_xpm);
-		break;
-	case 016:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, spellcheck_xpm);
-		break;
-		/* HTML toolbar stuff */
-	case 100:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, quick_start_xpm);
-		break;
-	case 101:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, body_xpm);
-		break;
-	case 102:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, bold_xpm);
-		break;
-	case 103:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, italic_xpm);
-		break;
-	case 104:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, underline_xpm);
-		break;
-	case 105:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, strikeout_xpm);
-		break;
-	case 106:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, paragraph_xpm);
-		break;
-	case 107:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, break_xpm);
-		break;
-	case 108:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, breakall_xpm);
-		break;
-	case 110:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, nbsp_xpm);
-		break;
-	case 111:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, anchor_xpm);
-		break;
-	case 112:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, hrule_xpm);
-		break;
-	case 113:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, image_xpm);
-		break;
-	case 114:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, center_xpm);
-		break;
-	case 115:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, right_xpm);
-		break;
-	case 116:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, comment_xpm);
-		break;
-	case 117:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, email_xpm);
-		break;
-	case 118:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, font_xpm);
-		break;
-	case 119:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, font_base_xpm);
-		break;
-	case 120:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fontp1_xpm);
-		break;
-	case 121:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fontm1_xpm);
-		break;
-	case 122:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fontpre_xpm);
-		break;
-	case 123:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fontsub_xpm);
-		break;
-	case 124:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fontsuper_xpm);
-		break;
-	case 125:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, thumbnail_xpm);
-		break;
-	case 127:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fonth1_xpm);
-		break;
-	case 128:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fonth2_xpm);
-		break;
-	case 129:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fonth3_xpm);
-		break;
-	case 130:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fonth4_xpm);
-		break;
-	case 131:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fonth5_xpm);
-		break;
-	case 132:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, fonth6_xpm);
-		break;
-	case 133:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, tablewhiz_xpm);
-		break;
-	case 134:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_xpm);
-		break;
-	case 135:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_tr_xpm);
-		break;
-	case 136:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_th_xpm);
-		break;
-	case 137:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_td_xpm);
-		break;
-	case 138:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table2_xpm);
-		break;
-	case 139:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_tr2_xpm);
-		break;
-	case 140:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_th2_xpm);
-		break;
-	case 141:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_td2_xpm);
-		break;
-	case 142:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, table_capt_xpm);
-		break;
-	case 143:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, framewhiz_xpm);
-		break;
-	case 144:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, frameset_xpm);
-		break;
-	case 145:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, frame_xpm);
-		break;
-	case 146:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, frameset2_xpm);
-		break;
-	case 147:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, frame2_xpm);
-		break;
-	case 148:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, frame_no_xpm);
-		break;
-	case 149:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, frame_base_xpm);
-		break;
-	case 150:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_xpm);
-		break;
-	case 151:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_submit_xpm);
-		break;
-	case 152:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_reset_xpm);
-		break;
-	case 153:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_text_xpm);
-		break;
-	case 154:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_hidden_xpm);
-		break;
-	case 155:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_textarea_xpm);
-		break;
-	case 156:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_radio_xpm);
-		break;
-	case 157:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_check_xpm);
-		break;
-	case 158:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, form_select_xpm);
-		break;
-	case 159:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_xpm);
-		break;
-	case 160:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_ul_xpm);
-		break;
-	case 161:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_ol_xpm);
-		break;
-	case 162:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_li_xpm);
-		break;
-	case 163:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_dl_xpm);
-		break;
-	case 164:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_dt_xpm);
-		break;
-	case 165:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_dd_xpm);
-		break;
-	case 166:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, list_menu_xpm);
-		break;
-	case 167:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, image_map_xpm);
-		break;
-	case 168:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, meta_xpm);
-		break;
-	case 169:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, embed_xpm);
-		break;
-	case 170:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, netscape_xpm);
-		break;
-	case 171:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, color_select_xpm);
-		break;
-	case 172:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, time_xpm);
-		break;
-	case 173:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, php3_xpm);
-		break;
-	case 174:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, ssi_xpm);
-		break;
-	case 175:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, rxml_xpm);
-		break;
-	case 176:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, color_select_small_xpm);
-		break;
-	case 177:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, open_small_xpm);
-		break;
-
-	case 180:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, cssnewstyle_xpm);
-		break;
-	case 181:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, cssspan_xpm);
-		break;
-	case 182:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, cssdiv_xpm);
-		break;
-	case 183:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, cssclass_xpm);
-		break;
-	case 184:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, cssstyle_xpm);
-		break;
-	case 185:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, dtd_xpm);
-		break;
-	case 186:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, head_xpm);
-		break;
-	case 187:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, linkjscript_xpm);
-		break;
-	case 188:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, jscript_xpm);
-		break;
-	case 189:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, linkstylesheet_xpm);
-		break;
-
-		/* everything else */
-	case 200:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, help_xpm);
-		break;
-	case 201:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, yes_xpm);
-		break;
-	case 202:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, no_xpm);
-		break;
-	case 203:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, ok_xpm);
-		break;
-	case 204:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, cancel_xpm);
-		break;
-
-	case 300:
-		pixm = gdk_pixmap_create_from_xpm_d(window, &mask, background, nothing_xpm);
-		break;
-	}
-
-	wpixmap = gtk_pixmap_new(pixm, mask);
-	gdk_pixmap_unref(pixm);
-	return wpixmap;
-}
