@@ -25,13 +25,11 @@
 #include <gtk/gtkwidget.h>
 #include <gdk/gdktypes.h>
 
-void get_main_menu(GtkWidget * window, GtkWidget ** menubar);
 void show_html_toolbar_cb(GtkWidget * w, gpointer data);
 void show_main_toolbar_cb(GtkWidget * w, gpointer data);
 void hide_html_toolbar_cb(GtkWidget * w, gpointer data);
 void hide_main_toolbar_cb(GtkWidget * w, gpointer data);
 GtkWidget *new_pixmap(int type, GdkWindow * window, GdkColor * background);
-void insert_char_cb(GtkWidget * widget, gint data);
 void toggle_main_toolbar_lcb(GtkWidget * w, gpointer data);
 void toggle_html_toolbar_lcb(GtkWidget * w, gpointer data);
 
