@@ -20,20 +20,14 @@
  *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include "default_include.h"
 #include <string.h>
-#include <gtk/gtk.h>
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
-
-#include "config.h"
 
 #include "bluefish.h"
 #include "undo.h"
-#include "interface.h"
-#include "debug.h"
-
+#include "document.h"
 
 typedef struct {
 	char *text;					/* text to be inserted or deleted */
@@ -44,87 +38,27 @@ typedef struct {
 } undo_t;
 
 /**********************************************************/
-void doc_insert_text_cb(GtkEditable * editable, const char *text, int len, int
-						*pos, gpointer d);
-void doc_delete_text_cb(GtkEditable * editable, int start, int end, gpointer d);
 void redo_cb(GtkWidget * wgt, gpointer cbdata);
 void undo_cb(GtkWidget * wgt, gpointer cbdata);
 void undo_all_cb(GtkWidget * wgt, gpointer w);
 void redo_all_cb(GtkWidget * wgt, gpointer w);
-void undo_list_add(filestruct * d, char *text, int start, int end, undo_op_t op);
+void undo_list_add(Tdocument * d, char *text, int start, int end, undo_op_t op);
 static GList *undo_list_delete(GList * list);
 static void undo_redo_common(gboolean which);
 
 /**********************************************************/
 
-/*
- * PUBLIC: doc_insert_text_cb, copied from doc.c in the gnotepad code
- *
- * callback for text widget for text insertion from keyboard typing.  note that
- * this routine and the next one (doc_delete_text_cb()), gets invoked for EVERY
- * key typed by the user.
- */
-void doc_insert_text_cb(GtkEditable * editable, const char *text, int len, int
-						*pos, gpointer d)
-{
-	char *buf;
-	if (main_v->props.cont_highlight_update) {
-		if (strchr(text, '"') != NULL) {
-			/* is there a smart way to check if a number is odd ? */
-			if ((main_v->current_document->need_highlighting == 1) || (main_v->current_document->need_highlighting == 3)
-				|| (main_v->current_document->need_highlighting == 5)) {
-				document_need_highlighting(main_v->current_document);
-			} else {
-				main_v->current_document->need_highlighting += 1;
-			}
-		} else if (strchr(text, '<') != NULL) {
-			if ((main_v->current_document->need_highlighting > 3)) {
-				document_need_highlighting(main_v->current_document);
-			} else {
-				main_v->current_document->need_highlighting += 2;
-			}
-		} else if (strchr(text, '>') != NULL) {
-			if ((main_v->current_document->need_highlighting == 2) || (main_v->current_document->need_highlighting == 3)) {
-				document_need_highlighting(main_v->current_document);
-			} else {
-				main_v->current_document->need_highlighting += 4;
-			}
-		}
-	}
-
-	buf = g_strndup(text, len);
-	DEBUG_MSG("doc_insert_text_cb, buf=%s\n", buf);
-	undo_list_add(d, buf, *pos, *pos + len, UndoInsert);
-	main_v->current_document->modified = 1;
-	DEBUG_MSG("doc_insert_text_cb, finished, modified = 1, need_highlighting=%d\n", main_v->current_document->need_highlighting);
-}								/* doc_insert_text_cb */
-
-
-/*
- * PUBLIC: doc_delete_text_cb, copied from doc.c in the gnotepad code
- *
- * callback for text widget for text deletion from keyboard typing
- */
-void doc_delete_text_cb(GtkEditable * editable, int start, int end, gpointer d)
-{
-	char *text;
-
-	text = gtk_editable_get_chars(editable, start, end);
-	undo_list_add(d, text, start, end, UndoDelete);
-	main_v->current_document->modified = 1;
-	DEBUG_MSG("doc_delete_text_cb, finished, modified=1\n");
-}								/* doc_delete_text_cb */
-
-
 
 /*
  * adds an undo item to the undolist.  if there exists items on the redo list,
  * removes them first.
  */
-void undo_list_add(filestruct * d, char *text, int start, int end, undo_op_t op)
+void undo_list_add(Tdocument * d, char *text, int start, int end, undo_op_t op)
 {
 	undo_t *undo;
 
+	DEBUG_MSG("undo_list_add, text=%p\n", text);
+	DEBUG_MSG("undo_list_add, strlen(text)=%d, text=%s\n", strlen(text), text);
 	if (strlen(text) == 0) {
 		return;
 	} else {
@@ -200,7 +134,7 @@ void redo_cb(GtkWidget * wgt, gpointer cbdata)
  */
 static void undo_redo_common(gboolean which)
 {
-	filestruct *d;
+	Tdocument *d;
 	undo_t *undo;
 	GList *tmp;
 	GList **srchead_cb, **srctail;
