@@ -32,7 +32,7 @@ typedef enum {
 	UndoDelete = 1, UndoInsert
 } undo_op_t;
 
-void undo_list_add(filestruct * d, char *text, int start, int end, undo_op_t op);
+void undo_list_add(Tdocument * d, char *text, int start, int end, undo_op_t op);
 
 void doc_insert_text_cb(GtkEditable * editable, const char *text, int len, int *pos, gpointer d);
 void doc_delete_text_cb(GtkEditable * editable, int start, int end, gpointer d);
