@@ -18,24 +18,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-
+#include "default_include.h"
 #include <stdio.h>
-#include <gtk/gtk.h>
 #include <string.h>
 
 #include <locale.h>
-#include <libintl.h>
-#include "intl.h"
 
 #include "cap.h"
-#include "config.h"
-#include "widgets.h"
 #include "wizards.h"
 #include "stringlist.h"
 #include "bluefish.h"
 #include "html.h"
-#include "interface.h"
-#include "debug.h"
+#include "document.h"			/* insert_text() */
+#include "interface.h"			/* statusbar */
 
 /* external functions I want to use */
 extern void flush_queue(void);
